# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 16.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V32
183
184
771
772
773
774
1156
1157
1159
1160
1417
1418
4347
4348
8282
8283
11264
11360
11843
11844
42607
42608
122880
122887
122888
122905
122907
122914
122915
122917
122918
122923
END
