+{
   locale_version => 1.31,
   entry => <<'ENTRY', # for DUCET v13.0.0
05F3      ; [*0316.001F.0002] # HEBREW PUNCTUATION GERESH
05F4      ; [*031D.001F.0002] # HEBREW PUNCTUATION GERSHAYIM
ENTRY
};
