# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 16.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'TokEHFunc'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'TokEHFunc'}{'missing'} = ''; # code point maps to the empty string

return <<'END';
13000		Classifier human being
13001		Classifier eating/drinking/speech/ silence/thoughts/feelings
13002		Classifier sitting
13003		Classifier supplication/hiding/rejection
13005		Logogram (to hide)
13006		Logogram (pure, clean)
13007		Classifier to libate
13009		Classifier sitting/weak/faint
1300A		Classifier joy/veneration
1300B		Classifier to lift, to carry
1300C		Classifier sailing/rowing
1300D		Phonemogram
1300E		Logogram (army)
1300F		Classifier rebel/enemy
13010		Classifier rebel, opponent
13011		Classifier death
13012		Logogram (to fall)
13013		Classifier bowing
13014	13015	Classifier youth/child
13016		Classifier child (royal)
13017		Logogram (old, old age)
13018		Logogram (elder)
1301A		Classifier statue
1301B		Classifier sovereign
1301C	1301D	Classifier force/effort
1301E		Logogram (vocative interjection)
1301F		Phonemogram/classifier messenger
13020		Logogram (to be high)
13021		Classifier upside down
13022		Classifier adoration
13023		Classifier turning away
13024		Classifier dancing
13026		Classifier wandering/displaced
13027		Logogram (to pound, to build)
13028		Logogram (to build)
13029	1302A	Logogram (brewer)
1302B	1302C	Logogram (Cusae)
1302D	1302E	Classifier divinity
1302F		Logogram (first person singular)
13030		Classifier king
13031		Logogram (first person singular)
13032		Classifier king
13033		Logogram (king of UE)
13034		Classsifier king
13035	13037	Classifier king
13038		Logogram (to guard)
13039		Logogram (relating to, belonging to)
1303A		Classifier foreigner
1303B	1303C	Logogram (to be noble)
1303D		Classifier name (deceased person)
1303E		Classifier image/statue/likeness
1303F		Classifier body/corpse/death
13040		Logogram (to sleep/to spend the night)
13041		Classifier enemy
13042		Logogram (an offering that the king gives)
13043		Classifier hacking
13044		Classifier driving away
13045		Logogram (to sprinkle, to scatter)
13046		Logogram (to turn back)
13047		Logogram (great one, chief)
13049		Classifier to lift, to carry
1304A		Logogram (the one who belongs to the god)
1304B		Logogram (the musician/Ihy)
1304C		Classifier personal name
1304D		Logogram (messenger)
1304E		Classifier occupation/relationship
1304F		Logogram (million, many)
13050		Classifier female
13051		Classifier pregnant
13052	13053	Classifier birth
13054		Classifier nursing, rearing
13055		Logogram weaver or  nurse
13056		Classifier nursing, rearing
13057		Classifier female royalty
13058		Classifier human being (together with A1)
13059		Logogram (the musician)
1305A	1305C	Logogram (Re)
1305F		Logogram (Thot)
13060		Classifier Khnum
13061		Logogram/phonemogram (who joins with life)
13062		Classifier Anubis/Wepwawet (divinity)
13063		Logogram (Seth)
13064		Classifier Min
13065		Logogram (Hathor)
13066	13067	Logogram (Maat)
13068		Logogram (million, many)
13069		Logogram (Amon)
1306B		Logogram (Amon is his strength (sꜣ-rꜥ name Ramses VI))
1306D		Logogram (Atum)
1306E		Classifier Montu (divinity)
1306F		Classifier Tatenen
13070		Classifier Ptah
13071		Logogram (Ptah)
13072		Phonemogram
13073		Classifier moon
13074		Logogram (Sekhmet)
13075		Logogram (Neith)
13076		Logogram (head)
13077		Phonemogram
13078		Classifier hair
13079		Phonemogram
1307A	1307B	Classifier eye related actions
1307C	1307E	Phonemogram
1307F		Logogram (to weep)
13080		Logogram (Udjat eye)
13081		Logogram 1/2
13082		Classifier pupil
13083		Classifier eyebrow
13084		Logogram 1/16
13085		Logogram 1/32
13086		Logogram 1/64
13087		Logogram (figure, image)
13088		Logogram (ear)
13089	1308A	Classifier nose
1308B		Phonemogram
1308C		Logogram (2/3)
1308D		Logogram (3/4)
1308E		Classifier lip, border, edge
1308F		Logogram (lips)
13090		Classifier blood
13091		Classifier breast
13093	13094	Logogram (spirit, essence)
13095		Classifier Nehebkau
13096	13097	Logogram (mortuary priest)
13098		Classifier enveloping, embracing, uniting
13099		Phonemogram
1309A	1309B	Logogram (to fight)
1309C		Logogram (negative particle)
1309D	1309F	Phonemogram
130A0		Logogram (to offer, to present)
130A1		Classifier force, effort
130A2		Classifier arm related movements or actions
130A3		Logogram (cubit)
130A4		Logogram (to protect)
130A5		Classifier governing/controlling
130A6		Logogram (to make holy)
130A7		Phonemogram
130A8		Logogram (scent, perfume, dew)
130A9		Classifier hand
130AA		Logogram (palm)
130AB		Phono-repeater
130AC		Classifier grasping/holding
130AD		Logogram (finger)
130AE		\20000
130AF		\30000
130B0		\40000
130B1		\50000
130B2		\60000
130B3		\70000
130B4		\80000
130B5		\90000
130B6		\50000
130B7		Classifier taking
130B8	130BA	Phonemogram
130BB		Classifier movement
130BC		Logogram (to come)
130BD		Classifier reverse movement
130BE		Classifier leg/foot
130BF		Classifier damage, injury
130C0	130C1	Phonemogram
130C2		Logogram (to be pure, to be clean)
130C3		Phono-repeater
130C4	130C5	Phonemogram
130C6		Logogram (hand)
130C7		Logogram (child, son, lad)
130C8		Classifier to engrave
130D2		Logogram (bull)
130D3		Classifier rage/aggression
130D4		Classifier calf
130D5		Classifier cow divinity
130D6		Classifier concern
130D7		Logogram (span (of horses)/horse)
130D8		Classifier donkey/ass
130D9		Logogram (kid)
130DA		Phono-repeater
130DB		Phonemogram
130DC		Classifier cow (cow of the sky)
130DD		Classifier ram
130DE		Phonemogram
130DF		Classifier pig
130E0		Phonemogram
130E1		Classifier dog/hound
130E2		Logogram (Anubis)
130E3		Logogram (privy to the secrets)
130E4		Classifier Anubis
130E5	130E6	Phonemogram
130E7		Logogram (Wepwawet)
130E8		Classifier Wepwawet
130E9		Logogram (Seth)
130EB		Logogram (Seth)
130EC		Classifier (lion)
130ED		Phonemogram
130EE		Classifier leopard
130EF		Classifier hippopotamus
130F0		Classifier elephant
130F1		Classifier to fortell
130F2		Classifier oryx
130F3		Logogram (Oryx nome, 16th nome of Upper Egypt)
130F4		Classifier gazelle
130F5		Classifier ibex
130F6		Logogram (rank, diginity)
130F7		Classifier rage, fury
130F8		Classifier monkey
130F9		Phonemogram
130FB		Classifier monkey (divinity)
130FC		Logogram (symbol of the cycle of time)
130FE		Classifier bull, ox, cattle
130FF		Phonemogram
13100		Classifier rage/aggression
13101		Phonemogram
13102		Logogram (beginning, front)
13103	13104	Phonemogram
13105		Classifier worth, dignity, renown
13106		Logogram (worth, dignity, renown)
13107		Logogram (strength)
13108	13109	Classifier throat associated action
1310A	1310B	Phonemogram
1310D	1310E	Logogram (new years day)
1310F		Logogram (horn)
13110		Logogram purification
13111		Phonemogram
13112		Classifier jaw
13113		Logogram (tongue)
13114		Logogram (ear)
13115		Logogram to hear, to listen
13116		Phonemogram
13117	13118	Classifier foreleg/arm
13119	1311A	Phonemogram
1311B		Classifier animal
1311C		Logogram (dappled, many-coloured)
1311D	13120	Phonemogram
13121		Logogram (belly, body)
13122		Phonemogram
13123		Logogram (heart, mind, wish)
13124	13125	Phonemogram
13126		Classifier spine, vertebrae
13127		Logogram (to cut)
13128		Classifier back, backbone
1312A		Phonemogram
1312B		Logogram (to be long, to stretch out)
1312C		Classifier slaughter/evil
1312D		Classifier rib
1312E		Classifier ribs (meat of ribs)
1312F		Phono-repeater
13130		Logogram (uterus, womb)
13131		Phonemogram
13132	13133	Logogram (to go round, to turn round)
13134		Classifier winding, intestine
13135	13136	Logogram (to go round, to turn round)
13137		Phono-repeater
13138	13139	Phonemogram
1313A		Classifier part of a body
1313B		Logogram (limbs, body)
1313D		Classifier excrement
1313E	13142	Phonemogram
13143		Logogram (Horus)
13144		Classifier falcon
13145		Logogram (lord)
13146		Classifier divine beings/divine things
13147		Logogram (Nemty (divinity))
13148		Logogram nmty (Nemty (divinity))
13149		Logogram (golden Horus)
1314A		Logogram (Re-Hor (usually in rꜥ-ḥr-ꜣḫ.ty)
1314B		Classifier bark of Sokar
1314C		Classifier cult image
1314E		Classifier cult image
1314F		Classifier falcon divinity
13150	13151	Logogram (mother)
13152		Logogram (the two ladies (i.e. Nekhbet and Wadjet)
13153	13154	Phonemogram
13156	13159	Phonemogram
1315A	1315B	Logogram (common folk, subjects, people)
1315C		Phonemogram
1315D		Logogram (Thot)
1315E		Classifier ibis
1315F		Logogram (to be red)
13160	13161	Phonemogram
13162		Logogram (souls)
13163		Classifier heron
13164		Logogram (to inundate)
13165		Phonemogram
13166		Classifier ostrich
13167	13168	Phonemogram
1316A		Classifier negative, bad
1316C		Phonemogram
1316D		Logogram (son)
1316E	13177	Phonemogram
13178		Classifier nest
1317A		Phonemogram
1317B		Classifier catching fish
1317C		Classifier feeding, eating
1317D		Logogram (soul)
1317E		Phonemogram
1317F		Logogram (bird, fowl)
13180		Phono-repeater
13181		Phonemogram
13182		Classifier people
13183		Classifier wing
13184	13185	Phonemogram
13186		Classifier claw
13187		Logogram (son)
13188		Phonemogram
13189		Classifier turtle
1318A		Classifier aggression
1318B		Classifier Sobek
1318C		Logogram (to gather)
1318D		Classifier Sobek
1318E		Phonemogram
1318F		Classifier divinity
13190		Logogram (one hundred thousand)
13191		Phonemogram
13192		Logogram (to go forth)
13193	13195	Phonemogram
13196		Logogram (eternity)
13197		Classifier female divinity
13198		Classifier female divinity (Wadjet)
13199		Classifier coiling, winding
1319A		Classifier snake/uraeus
1319B		Phonemogram
1319C		Phono-repeater
1319D		Logogram (fish)
1319E		Phonemogram
1319F		Phono-repeater
131A0		Logogram (scale)
131A1		Classifier rage, anger
131A2		Classifier catfish
131A3		Logogram (to become)
131A4		Logogram (king of LE)
131A5		Logogram (King of UE and LE)
131A7		Classifier locust
131A8		Classifier centipede
131A9		Phonemogram
131AB		Classifier scorpion
131AC		Logogram/phonemogram (type of beetle)
131AD		Classifier tree, product of a tree
131AE		Classifier product of a tree
131AF	131B2	Phonemogram
131B3		Logogram (year)
131B4	131B5	Logogram (time/season)
131B6		Classifier youth, vigour, fresh
131B7		Phonemogram
131B8		Classifier lotus flower
131B9		Classifier lotus bud
131BA		Classifier offering
131BB		Logogram (to offer)
131BC		Phonemogram
131BD		\2000
131BE		\3000
131BF		\4000
131C0		\5000
131C1		\6000
131C2		\7000
131C3		\8000
131C4		\9000
131C5	131C6	Phonemogram
131C7	131C8	Logogram (Lower Egypt)
131C9		Phonemogram
131CA		Logogram (Lower Egypt)
131CB	131CC	Phonemogram
131CD		Phonemogram/logogram (to come)
131CE		Phonemogram
131CF		Logogram (marshland, country)
131D0		Logogram (herb, plant)
131D1	131D2	Phonemogram
131D3		Logogram (King of UE)
131D4		Phonemogram
131D5		Logogram (land)
131D6	131D8	Logogram (Upper Egypt)
131D9		Logogram (the 10 of UE)
131DA		Logogram (Upper Egypt)
131DB	131DC	Logogram (to be sweet)
131DD	131DF	Classifier growing
131E0		Logogram (grain, barley, corn)
131E1	131E2	Classifier grain, barley, corn
131E3		Logogram (emmer)
131E4		Classifier heap, quantity
131E5	131E6	Phonemogram
131E7		Classifier flax
131E8		Classifier granular product
131E9	131EA	Phonemogram
131EB		Classifier wood/timber
131EC		Phonemogram
131ED		Logogram (wine)
131EE		Phonemogram
131EF		Logogram (sky)
131F0	131F1	Classifier night
131F2		Classifier storm
131F3	131F4	Logogram (the sun, Re)
131F5		Logogram (course (of the day), daily requirements)
131F6		Classifier light, shining, rising
131F7	131F8	Phonemogram
131F9		Logogram (month)
131FA		Classifier moon
131FB		Logogram (half-month (festival))
131FC		Logogram (star)
131FD		Classifier (netherworld)
131FE	131FF	Logogram (land)
13200		Logogram (island)
13201		Phonemogram
13203		Logogram (horizon-dweller)
13204		Classifier riverbank
13205	13206	Logogram (riverbank)
13207		Classifier geographical location
13208		Logogram (nome, district)
13209		Classifier foreign land, desert
1320B		Phonemogram
1320C		Logogram (horizon)
1320D	1320E	Phonemogram
1320F		Logogram hill, mound
13210		Logogram (road)
13211		Classifier clay
13212	13213	Classifier medicaments, incense, oil
13214		Classifier metal objects
13215		Logogram (metal)
13216		Phonemogram
13217		Logogram (water)
13218	1321C	Phonemogram
1321D		Logogram (to go)
1321E	1321F	Phonemogram
13220		Logogram (Memphis (the white wall, first nome of Lower Egypt))
13221		Logogram (2nd nome of Lower Egypt)
13222		Logogram (West, 3rd nome of LE)
13223		Logogram (Neith-south, 4th nome LE)
13224	13225	Logogram (Neith-north, 5th nome of LE)
13226		Logogram (6th nome of LE)
13227		Logogram (7th nome of Lower Egypt)
13228		Logogram (8th nome of Lower Egypt)
13229		Logogram (9th nome of UE)
1322A		Logogram (10th nome of LE)
1322B		Logogram (11th nome of LE)
1322C		Logogram (12th nome of LE)
1322D		Logogram (13th Lower Egyptian nome)
1322E		Logogram (14th upper Egyptian nome)
1322F		Logogram (Thot nome, 15th nome of LE)
13230		Logogram (First-of-fishes nome (16th nome of LE))
13231		Logogram (Behdet, 17th Lower Egyptian nome)
13232		Logogram (17th Lower Egyptian nome (Diospolis))
13236		Logogram (Nubia, 1st Upper Egyptian nome)
13237		Logogram (Throne of Horus (Edfu, 2nd nome of UE))
13238		Logogram (3rd nome of Upper Egypt)
13239		Logogram (Thebes)
1323A		Logogram (The two gods, 5th nome of UE)
1323B		Logogram (Iqer, 6th nome of UE)
1323C		Logogram (Bat (7th nome of Upper Egypt))
1323D		Logogram (8th nome of Upper Egypt)
1323E		Logogram (9th nome of Upper Egypt)
1323F	13240	Logogram (Wadjet, 10th nome of UE)
13241		Logogram (11th nome of Upper Egypt)
13242		Logogram (11th Upper Egyptian nome (commonly under stẖ/stš/šꜣ)
13243		Logogram (12th Upper Egyptian nome)
13244		Logogram (13th Upper Egyptian nome)
13245		Logogram (14th Upper Egyptian nome)
13246		Logogram (Hermopolis magna, 15th nome of UE)
13247		Logogram (Oryx nome, 16th nome of Upper Egypt)
13248		Logogram (Anubis nome (17th nome of Upper Egypt))
13249		Logogram (18th nome of UE (known as nmty as well))
1324B		Logogram (place of Igai, 19th nome of Upper Egypt)
1324C		Logogram (20th Upper Egyptian nome)
1324D		Logogram (21th Upper Egyptian nome)
1324E	1324F	Logogram (22th nome of Upper Egypt)
13250		Logogram (house, domain)
13251		Logogram (scriptorum, school (house of life))
13252		Logogram (treasury)
13253		Logogram (invocation offering)
13254	13255	Phonemogram
13257		Logogram (temple, mansion, estate)
1325E		Logogram (temple, mansion, estate)
1325F		Logogram (the great domain, temple)
13260		Logogram (Nephthys (divinity))
13261		Logogram (Hathor (divinity))
13262		Logogram (mansion of life)
13265	13266	Logogram (palace)
13267		Classifier enfolding, enclosing, walling in
13268		Classifier gateway
13269		Logogram (court)
1326A		Logogram (portal, portico)
1326B		Phonemogram
1326C		Classifier shrine, chapel
1326D		Classifier shrine
1326E		Logogram (shrine, row of shrines)
1326F		Classifier sanctuary, shrine
13271		Logogram (pavilion, hall, booth)
13272		Classifier booth
13273		Logogram (jubilee, sed-festival)
13274		Classifier pyramid, tomb
13275		Classifier solar temple
13276		Classifier obelisk
13277		Classifier solar temple
13278		Classifier stela
13279		Classifier hall, office
1327A	1327C	Phonemogram
1327D		Logogram (pole, support)
1327F		Logogram (gate)
13280		Classifier doorway
13281		Classifier palace façade
13283	13284	Phonemogram
13285		Logogram (wall)
1328A		Classifier overthrow, demolish
1328B		Classifier passage
1328C		Classifier stone, brick, pebble
1328D		Logogram stairway
1328E		Classifier ascending, being high
1328F	13290	Phonemogram
13291		Logogram (office, rank, function)
13292	13293	Logogram (harim, inner chamber)
13294		Logogram (Hierakonpolis)
13295		Logogram (time, occasion)
13296		Logogram (city, village)
13297		Classifier treshing floor
13299		Phono-repeater/classifier (time, occasion)
1329A		Logogram (granary)
1329B		Classifier movement
1329C		Classifier to upset, to overturn
1329E		Classifier bark/boat
132A0		Logogram (to loosen, to explain)
132A1		Logogram (wind, breath, air)
132A2	132A5	Phonemogram
132A6		Logogram (steering oar)
132A7		Classifier mooring post
132A8		Logogram (seat, throne, place)
132A9	132AA	Phonemogram
132AB		Classifier headrest
132AC		Classifier box
132AD		Classifier coffin
132AE		Classifier fire, flame, heat
132AF		Classifier altar
132B0	132B1	Logogram (altar)
132B2		Classifier festival
132B3		Classifier offering table/jar-stand
132B5		Logogram (offering)
132B6		Classifier fumigation/censing
132B7		Logogram (to fumigate, to cense)
132B8		Logogram (incense)
132B9		Logogram (god)
132BA		Classifier natron
132BB	132BC	Logogram (necropolis)
132BD		Phonemogram
132BE		Classifier standard
132BF		Logogram (west, right side)
132C0		Logogram (west)
132C1		Phonemogram
132C2		Classifier fray, battle
132C3		Logogram (Nefertem)
132C4	132C5	Logogram (8th nome of Upper Egypt)
132C6		Logogram (Thebes)
132C7	132C8	Logogram (Seshat (divinity))
132C9		Logogram (Letopolis)
132CA		Logogram (Min (divinity))
132CB	132CC	Logogram (Neith (divinity))
132CD		Phonemogram
132CE		Logogram (Neith (divinity))
132CF		Logogram (Bat (7th nome of Upper Egypt))
132D0		Logogram (shrine, row of shrines)
132D1		Phonemogram
132D2		Classifier crown
132D3		Logogram (Upper Egypt)
132D4		Phonemogram
132D5		Classifier crown
132D6	132D7	Classifier double crown
132D8		Logogram (Lower Egypt)
132D9		Classifier crown
132DA		Logogram (Atef-crown)
132DB		Logogram (double plumes/two feather crown)
132DC		Logogram (strip of cloth, fillet)
132DD		Logogram (necklace, collar)
132DE		Logogram (gold)
132DF		Phonemogram
132E0		Logogram (silver)
132E1		Logogram (white gold, fine gold, electrum)
132E3	132E5	Logogram (faience, glass)
132E6		Phonemogram
132E7		Classifier necklace
132E8		Logogram (sealbearer)
132E9		Logogram (seal, lock, sealing)
132EA		Logogram (necklace, collar)
132EB		Phonemogram
132EC		Logogram (to unite, to assemble)
132ED		Classifier to tie, to bind
132EE		Classifier garment, mantle, kilt
132EF		Classifier kilt, royal apron
132F0		Logogram (loincloth, garment)
132F2		Logogram (clothing)
132F3		Classifier clothing
132F4	132F7	Phonemogram
132F8		Classifier sandal
132F9		Logogram (life)
132FA		Classifier shadow, shade
132FC		Logogram (shadow, shade)
132FD		Logogram (fan)
132FE		Phonemogram
132FF		Logogram (shepherd's crook)
13300		Phonemogram
13301		Classifier sceptre
13302	13303	Phonemogram
13304		Classifier staff, sceptre
13305		Logogram (flagellum)
13306	13307	Phonemogram
13308		Classifier striking, hitting
13309	1330D	Phonemogram
1330E		Logogram (carpenter, shipwright)
1330F		Classifier axe, battle-axe
13310	13311	Phonemogram
13312		Classifier bow, weapon
13313		Phonemogram
13314		Logogram (bow)
13315		Phonemogram
13317		Phonemogram
13318	13319	Phono-repeater
1331A		Phonemogram
1331B		Classifier curved blade, scimitar
1331C		Classifier strong arm, power, strength
1331D		Logogram (chariot)
1331E		Logogram (follower, retainer)
1331F		Classifier bone
13320		Classifier harpoon
13321		Logogram (one, sole)
13322	13323	Phonemogram
13324		Classifier catching, netting
13325		Phonemogram
13326		Classifier catching, netting
13327		Classifier weaving, woven material
13328		Phonemogram
13329		Logogram (place of slaughter)
1332A		Classifier cutting, slaughter
1332B	1332D	Phonemogram
1332E		Logogram (butcher)
13330		Classifier knife
13331		Logogram (knife)
13332		Classifier shield
13333	13334	Phonemogram
13335		Phonemogram (in mꜣꜣ, to see)
13336	13338	Phonemogram
1333B	1333C	Phonemogram
1333D		Classifier grain/barley
1333E		Logogram (harvest, crop)
1333F	13340	Logogram (bushel (a corn measure, 10 hin))
13341		Classifier plough/plowed material
13342		Phono-repeater
13343	13345	Phonemogram
13346		Logogram (to found, to establish, to hunt, to lay (a trap))
13347	13349	Phonemogram
1334A		Phono-repeater
1334B	1334C	Phonemogram
1334D		Logogram (craftsman)
1334E		Logogram (craft)
1334F		Logogram (to open)
13350		Classifier to open
13351	13354	Phonemogram
13355		Classifier to restrain
13356		Logogram (to pound, to crush)
13357		Phono-repeater
13358	1335B	Phonemogram
1335C		Logogram (razor)
1335D		Logogram (balance)
1335E		Classifier balance, scale
1335F		Phonemogram
13360		Classifier plummet
13361		Logogram (staff)
13362		Logogram (100)
13363		200
13364		300
13365		400
13366		500
13367		600
13368		700
13369		800
1336A		900
1336B		500
1336C		Logogram (to drag, to pull, to draw)
1336D	1336F	Phonemogram
13370		Logogram (foundation)
13371	13372	Phonemogram
13373		Classifier cloth
13374	13375	Phonemogram
13376		Logogram (to surround, to encircle)
13377		Logogram (name)
13378		Classifier half, part, portion
1337C		Classifier papyrus/book/document
1337D		Phonemogram
1337E		Classifier papyrus/book/document
1337F	13382	Phonemogram
13383	13384	Logogram (protection)
13385		Logogram (stable)
13386		Logogram (10)
13387		20
13388		30
13389		40
1338A		50
1338B		60
1338C		70
1338D		80
1338E		90
1338F		20
13390		30
13391		40
13392		50
13393		Logogram (stable)
13394	1339F	Phonemogram
133A1	133A3	Phonemogram
133A4		Classifier linen
133A5		Classifier sack, bundle
133A6		Classifier (perfume)
133A7		Logogram (linen)
133A8		Phonemogram
133A9		Phono-repeater
133AA		Phonemogram
133AB		Classifier to bandage, to wrap
133AC		Logogram (Tit-amulet)
133AD		10
133AE		20
133AF		Classifier oil, unguent
133B0		Phonemogram
133B1		Logogram (festival)
133B3		Logogram (festival)
133B4		Logogram (lector priest)
133B5		Classifier cauldron
133B6		Classifier granite
133B7		Phono-repeater
133B8		Phonemogram
133BA	133BD	Phonemogram
133BE		Classifier red (earthenware) vessel
133BF		Phonemogram
133C1		Logogram (to be cool, to cool)
133C2		Classifier libation water
133C3	133C5	Phonemogram
133C7		Phonemogram
133C8		Classifier milk
133C9		Classifier wine
133CA	133CB	Logogram (beer)
133CC		Phonemogram
133CE	133CF	Phonemogram
133D0		Logogram (bread)
133D1		Classifier bread/food
133D2		Classifier Festival
133D3		Phonemogram
133D4		Classifier bread, Festival, Phonemogram t, Logogram t (bread), Phono-repeater: sn, fḳꜣ
133D5		Phono-repeater
133D6		Classifier offering, cake, loaf
133D8		Classifier food
133D9		Phonemogram
133DA		Classifier bread
133DB		Classifier abstract words
133DC		Logogram (papyrus scroll, book)
133DD		Classifier writing, things written
133DE	133DF	Logogram (scribe)
133E0		Phonemogram
133E1		Classifier game, gamepiece
133E2		Classifier harp
133E3		Classifier sistrum
133E4		Classifier semogram
133E5		Classifier plural
133E8	133EB	Classifier plural
133ED		Phonemogram
133EE		Logogram (2)
133EF		Substitute for dangerous signs
133F0		Classifier divinity (replacing G7)
133F1		Classifier death
133F2		Phonemogram
133F3		Classifier round, oval
133F4		Classifier divide
133F5		Classifier break
133F6	133F7	Phonemogram
133F9		Classifier semogram
133FA		Logogram (one, sole)
133FB		Logogram (two)
133FC		Logogram (three)
133FD		Logogram (four)
133FE		Logogram (five)
133FF		Logogram (six)
13400		Logogram (seven)
13401		Logogram (eight)
13402		Logogram (nine)
13403		Logogram (five)
13404		Logogram (one, sole)
13405		Logogram (two)
13406		Logogram (three)
13407		Logogram (four)
13408		Logogram (five)
13409		Logogram (six)
1340A		Logogram (seven)
1340B		Logogram ḫmn (eight)/Logogram ḫmnw (Hermopolis)
1340C		Logogram (nine)
1340D		Phonemogram
1340E		Classifier bad/evil
1340F		Classifier efflux, smell (i.e., excrement)
13410		Phonemogram
13411		Classifier oar
13412		Phono-repeater
13413	13414	Classifier to present
13416		Logogram (nome, district)
13417		Classifier suffering
13418		Classifier writing
13419	1341B	Phonemogram
1341C		Logogram (side, half)
1341D		Phonemogram
1341E		Logogram (side, half)
1341F	13420	Phonemogram
13421		Classifier shrine, chapel
13422		Phonemogram
13423	13424	Logogram (to judge, to separate)
13425	13426	Logogram (to press, to cling (to))
13427	1342B	Phonemogram
1342C	1342D	Logogram (ornament)
1342E		Logogram (Nubia)
13460	13461	Classifier human being
13462		Logogram (first person singular)
13463		Classifier human being
13464		Classifier court, entourage
13465		Classifier occupation/relationship (fisherman or brewer)
13466		Classifier to conspire, to brood
13467		Classifier personal name
13468		Logogram (enemies)
13469		Classifier human being (poor man)
1346A		Classifier human being
1346B		Logogram (vocative interjection)
1346C		Logogram (first person singular)
1346D		Classifier sitting
1346F		Classifier eating/drinking/speech/ silence/thoughts feelings
13470		Classifier speech/sound
13471		Classifier speech/silence
13472		Classifier acclaim, speaking
13473		Classifier speech/silence
13474		Classifier sitting/weak/faint
13476		Logogram (praise, worship)
13477		Classifier adoration
13478		Classifier supplication/hiding/rejection
13479		Classifier harpooner/priest
1347A		Classifier reverence
1347B		Classifier enemies
1347C		Classifier prisoner
1347D		Classifier human being/personal name
1347E		Classifier joy
1347F		Logogram (joy)
13480		Classifier making music
13481	13482	Classifier joy
13483	13484	Classifier human being
13485		Logogram (musician)
13486		Classifier bald
13487		Classifier music
13489		Classifier  to totter
1348A		Classifier foreigner (nubian)
1348B	1348C	Logogram (to fraternize)
1348D		Classifier deserter/wanderer
1348E		Classifier to wrestle
1348F		Classifier to defecate
13490		Classifier to be short
13491		Logogram (to pour, to drain)
13492		classifier (the cold one)
13493		Phonemogram
13494		Classifier old man
13496		Classifier hair related
13498		Phonemogram
13499		Logogram (myrrh)
1349A		Classifier official, noble
1349B		Classifier vocative interjection
1349C		Logogram (to bend)
1349D		Classifier attacker
1349E		Classifier lifting/carrying
134A1		Classifier bowing
134A2		Logogram (Sem priest)?
134A3	134A4	Classifier bald
134A5		Classifier adoration
134A7		Classifier leaping, bounding
134A8		Classifier bowing
134AA		Classifier bowing
134AB		Logogram (kissing the land)
134AC		Classifier to twist
134AD		Phonemogram
134AF		Logogram (bowing down)
134B0		Classifier falling
134B1		Logogram (to overthrow, to cast down)
134B2		Classifier enemy
134B3		Classifier bowing/lowering to the ground
134B5	134B6	Logogram (kissing the land)
134B8		classifier bowing, lowering to the ground
134B9		Classifier corpse
134BA		Classifier to overthrow
134BB		Classifier corpse
134BC		Classifier to sleep/to awaken
134BD		Classifier lying on one side
134BF		Classifier swimming
134C0		Phonemogram
134C1		Classifier swimming
134C3	134C4	Phonemogram
134C5		Classifier swimming
134C6		Logogram (official, noble)
134C7		Logogram (9th nome of UE)
134C8		Classifier statue
134C9		Logogram (elder)
134CA		Logogram (elder (in ḥr-wr, Haroeris))
134CB		Classifier sovereign
134CD		Classifier wisdom
134CE		Logogram (elder of the court)
134CF		Classifier statue
134D0		Classifier to cut down
134D1		Logogram (great)
134D2	134D3	Logogram (great one, chief)
134D4		Logogram (great)
134D6		Logogram (great one, chief)
134D7		Classifier noble
134D8		Classifier Orion
134D9		Logogram (son/child of)
134DA		Classifier lector priest
134DB	134DC	Logogram (humankind, patricians)
134DD		Logogram (to drink)
134DE		Classifier swallowing
134DF		Logogram (to drink)
134E0		Classifier drinking
134E1	134E3	Classifier lifting/carrying
134E4		Pictogram kneeling making offering
134E5	134E6	Classifier work
134E7		Phonemogram
134E8	134E9	Classifier work
134EA	134EB	Logogram (to lift, to carry)
134EC		Logogram (to lift the arm)
134ED		Logogram (Heh (divinity))
134EE		Logogram (to suppport, to raise)
134EF		Classifier to hold up, to support (in the title ꜥḫ-p.t)
134F0		Classifier vocative interjection
134F1		Phonemogram (in snm.t, the island Biga)
134F2		Phonemogram
134F3		Phonemogram/logogram (his heart)
134F4		Classifier people
134F6		Logogram (farmer/gardener)
134F7		Phonemogram (from fꜣꞽ ḥr)
134F8		Classifier reaping
134F9		Classifier lector priest
134FA		Phonemogram
134FB		Logogram (his name)
134FC		Phonemogram
134FD		Logogram (to lift, to carry)
134FE		Classifier to lift, to carry
134FF		Logogram (work)
13500		Phonemogram
13501	13502	Logogram (to raise up offerings)
13504		Logogram (to suppport/to raise the sky)
13505		Phonemogram
13507	13508	Phonemogram
1350A		Classifier offering
1350B	1350C	Logogram (to bring)
1350D	1350E	Classifier force/effort
1350F		Classifier death
13510	13512	Logogram (pure, clean)
13513	13514	Logogram (wab-priest)
13516		Classifier to libate
13517	13518	Logogram (pure, clean)
13519		Logogram (to be pure, to be clean)
1351A		Logogram (pure, clean)
1351C		Logogram (wab-priest)
1351D	1351E	Logogram (pure, clean)
1351F	13520	Classifier pouring
13522		Logogram (to pour)
13523		Logogram (to libate)?
13524		Classifier greeting
13525		Classifier to sprinkle, to scatter
13526		Logogram (to sprinkle, to scatter)
13527		Logogram (to hide)
13528	13529	Classifier hiding/hidden
1352A		Logogram (to hide)
1352B		Classifier melting/casting
1352C		Logogram (overseer of the deserts)
1352D	1352E	Classifier grinding
1352F		Classifier (to measure)
13530		Classifier reaping/harvesting
13531		Logogram (to drive in the mooring post)
13533	13534	Logogram (to pound, to build)
13535	13536	Logogram (to build)
13537	13539	Classifier building/constructing
1353A		Logogram (to create, to shape)
1353B		Classifier to create, to shape
1353C	1353D	Classifier to create
1353E		Logogram (to sieve, to press)
1353F		Logogram (brewer)
13540		Classifier pot-stand/sideboard
13541		classifier to punt/pole (a boat)
13542		Uncertain, classifier?
13543		Logogram (builders)
13546		Uncertain (in sꜣ.w (domain), and in an offering list after ḥnḳ.t)
13547		Classifier to open (a scroll)
13548		Logogram (scribe)
13549		Classifier occupation
1354B		Logogram (to strike)
1354C		Logogram (to bend down)
1354D		Logogram (slaughtered oryx)
1354E		Logogram (to guard)
1354F		Logogram (herdsman)
13550		Classifier herdsman
13551		Classifier foreigner (asiatic)
13552		Logogram (relating to, belonging to)
13553		Logogram (to guard)
13554		Logogram (foreigner)
13555	1355B	Logogram (to guard)
1355C		Logogram (relating to, belonging to)
1355D		Classifier foreigner
1355E		Classifier enslave
1355F		Uncertain
13560	13561	Classifier bow-people, nomads
13562		Classifier foreigner
13563		Classifier wandering/displaced
13564	13565	Logogram (herdsman)
13566		Logogram (wanderer, displaced)
13567		Logogram (prospector)
13568	13569	Logogram (herdsman)
1356B		Logogram (elder)
1356C		Classifier elder
1356E		Logogram (to protect)
1356F		Logogram (to erect)
13570		Logogram (to erect the Djed pillar)
13571		Classifier erecting the djed-pillar (group classifier for sꜥḥꜥ-ḏd-ꞽn-ꞽr.yw-ḫt-n(y)-sw.t)
13572		Classifier erecting
13573		Logogram (elder)
13574		Logogram (to be old)
13575		Logogram (myrrh)
13576		Classifier divinity
13577		Logogram (Sem-priest)
13578		Logogram (to be strong)
13579	1357A	Logogram (Onuris)
1357C		Logogram (prospector)
1357E		Logogram (the one who opens the two doors of the sky)
1357F		Logogram (gatekeeper)
13580		Phonemogram
13582		Logogram (to protect)
13583		Logogram (to raise the sail)
13584		Classifier presenting
13585		Logogram (to bring)
13586		Logogram (lord of the two lands)
13587		Classifier to spread
13588		Phono-repeater
13589		Classifier to uproot
1358A	1358C	Phonemogram
1358D		Logogram (to illuminate)
1358E		Logogram (army)
1358F		Classifier angry one
13590		Logogram (messenger/killer)
13591		Classifier driving away
13592		Classifier slayer
13593		Classifier (harpooner)
13594		Classifier driving away
13595		Classifier dancing
13596		Logogram (to be strong)
13597		Classifier battle
13598		Classifier ?
13599		Logogram (to be strong)
1359C		Classifier army
1359D		Classifier foreigner
1359E	1359F	Classifier hiding/hidden
135A1		Classifier runner (foreign)
135A2		Classifier army (semitic loanword)
135A4		Classifier to trample
135A5		Logogram (army)
135A6		Classifier soldiery
135A7		Logogram (army)
135A8	135A9	Logogram (army)?
135AA		Logogram (army)
135AB		Logogram (1st nome of Upper Egypt)
135AC		Logogram (army)
135AD		Logogram (army)?
135AF		Classifier rebel/enemy
135B0		Classifier rebel
135B1		Classifier enemy?
135B2	135B3	Classifier enemy
135B4		Classifier rebel
135B5		Logogram (chiefs)
135B6		Classifier Syrian
135B7		Classifier enemy/rebel (Xerxes)
135B8		Classifier evil one
135B9		Classifier enemy/rebel (Xerxes)
135BA		Classifier rebel
135BB		Classifier enemy
135BC		Logogram (rebel)
135BE	135BF	Logogram (rebel)
135C1		Classifier rebel
135C2		Classifier enemy
135C3		Classifier rebel, enemy
135C4		Classifier enemy
135C5	135C6	Classifier rebel
135C7		Classifier rebel, enemy
135C8		Classifier foes, hostile forces`
135C9		Classifier enemy
135CA		Classifier foreigners (as enemies)
135CB	135CC	Classifier rebel
135CD		Logogram enemy
135CF		Logogram (rebel)
135D0		Logogram enemy/rebel
135D3		Classifier enemy
135D4		Classifier bow-people, nomads
135D5		Logogram (prisoner)
135D7		Logogram (foreigner)
135D8		Classifier to drive away
135D9		Logogram (to bend down, to subdue)
135DA		Classifier foreigner
135DC		Classifier foreign people
135DD		Classifier weak, downcast
135DE		classifier dancing
135DF		Classifier joy, jubilation
135E0		Classifier dancing
135E1	135E2	Classifier dance
135E3		Classifier youthful soldier
135E4		Classifier fear/veneration
135E5	135E8	Classifier dancing
135E9		Classifier fear/veneration
135EB		Logogram (the great god)
135ED		Logogram (to make music)
135EE		Logogram (the great god)
135EF		Logogram (the King of Lower Egypt)
135F0		Classifier divinity
135F1		Logogram (Ihy (divinity))
135F2		Logogram (the musician)
135F3		Logogram (the great god)
135F4		Logogram (King of UE)
135F5	135F6	Logogram (the great god)
135F7		Logogram (Ihy (divinity))
135F8	135FA	Logogram (Harsomtus)
135FB		Logogram (to sing)
135FC		Phonemogram
135FD		Classifier musician
135FE		Classifier playing music
135FF		Classifier drum
13600		Classifier striking a drum
13601		Logogram (musician/percussionist)
13602		Classifier beating, striking
13603		Classifier lute player
13604		Logogram (Cusae)
13605	13606	Classifier hunter, scout
13607		Logogram (to be strong, valiant)
13608		Logogram (the good beginning)
13609		Logogram (Cusae)
1360A	1360B	Logogram (to be strong, valiant)
1360C		Classifier chariot
1360D		Logogram (triomphator)
1360F		Logogram (butchery, animals for sacrifice)
13610		Pictogram ((with) a plough, (with) a yoke of oxen, (as) the first of men)
13611		Logogram (part of the sꜣ-rꜥ nb ḫꜥ.w construction)
13612		Phonemogram/logogram (part of the sꜣ-rꜥ nb ḫꜥ.w construction)
13613		Classifier?
13614		Phonemogram aromatic resin (styrax?)
13615		Phonemogram (lapis-lazuli)
13616		Logogram (triomphator)
13617		Phonemogram (lapis-lazuli)
13618		Logogram (to go around)
13619		Classifier hunter, scout
1361A		Classifier priest
1361B		Phonemogram
1361D		Classifier youth/child
1361E		Classifier to sit, to be comfortable
1361F		Phonemogram
13620		Classifier musician
13621		Classifier child, youth, young man
13622		Logogram (weaned child)
13623		Phonemogram
13625	13626	Logogram (Son of Re)
13627		Phonemogram
13628	13629	Classifier child
1362A		Phonemogram
1362C	1362D	Phonemogram
1362E		Classifier protector
1362F	13630	Phonemogram
13632		Classifier Orion
13633		Classifier child divinity
13634		Classifier child
13636		Logogram (son/child of)
13637		Logogram (crowns, appearances)
13638		Logogram (son/child of)
13639		Classifier child
1363B		Phonemogram
1363C		Classifier expelling, spitting
1363D		Logogram (dwarf, pigmy)
1363E	13640	Classifier revered person
13641		Logogram (to be noble)
13642		Logogram (the noble speech)
13643		Classifier revered person
13644		Logogram/phonemogram (costly offerings)
13645		Logogram (noble, splendid)
13646		Logogram (to be noble)
13647		Classifier divinity
13648		Classifier to abide, to occupy
1364A		Logogram (to be noble)
1364C		Classifier noble
1364D		Logogram/phonemogram (costly offerings)
1364E		Logogram (to be noble)
13650		Classifier revered person
13651		Logogram (Harsomtus)
13652		Classifier divinity
13654	13655	Classifier divinity
13656	13657	Classifier king
13659		Logogram (first person singular)
1365B		Classifier divinity
1365C	1365D	Logogram (first person singular)
1365E		Logogram (powerful one)
1365F		Logogram (majesty)
13660		Logogram (king)
13661		Logogram (Khepri)
13662		Logogram (to rule)
13663		Logogram (ruler of the 9th nome of UE)
13664		Logogram (ruler)
13665		Classifier statue
13666		Logogram (sovereign)
13667		Logogram (noble, splendid)
13668		Classifier sovereign
13669		Logogram (sovereign)
1366C		Classifier personal name
1366D		Classifier statue
1366E		Classifier praying, worshipping
1366F		Classsifier king
13670		Classifier divinity
13671		Classsifier king
13672		Classifier divinity
13673	13674	Classsifier king
13675		Classifier divinity
13676		Logogram (king of UE)
13677	13678	Classsifier king
13679		Classifier divinity
1367A	1367C	Logogram (king of UE)
1367D		Logogram (majesty)
1367E		Logogram (he of heliopolis)
1367F		Logogram (the white crown)
13680		Classifier divinity
13681		Classifier Osiris
13682		Classsifier king
13684	13685	Logogram (king of UE)
13686		Logogram (king of UE and land, when occuring together with king of LE forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy)
13687		Logogram (king of UE and land when occuring together with red crown wearing variant forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy)
13688		Logogram (King of UE)
13689		Logogram (Osiris)
1368A	1368E	Logogram (king of LE)
1368F		Classifier king
13690		Logogram (king of LE)
13691		Classifier sovereign
13692		Classifier king
13693		Logogram (King of LE and land, when occuring together with King of UE forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy)
13694		Logogram (King of LE and land, when occuring together with a white crown variant forms n(.y)-sw.t-bꞽ.ty nb tꜣ.wy)
13695		Logogram (King of UE)
13696		Logogram (to run)
13697		Logogram (an offering that the king gives)
13698		Phonemogram
13699		Logogram (Atum)
1369A		Logogram (first person singular)
1369B		Logogram (king of ULE)
1369C	1369D	Classifier king/divinity
1369E		Logogram (Atum)
1369F		Classifier divinity
136A0		Logogram (Atum)
136A1		Classifier sovereign
136A2		Logogram (king of ULE)
136A4		Pictogram prostate offering a vase of myrrh
136A5		Logogram (sovereign)
136A6	136A7	Classifier sovereign
136A9	136AA	Logogram (sovereign)
136AC		Logogram/phonemogram (in ꜥnḏ.ty (Busiris))
136AD		Logogram (9th nome of UE)
136AE		Classifier majesty (specifically referring to Shu)
136AF		Classifier divinity (Geb)
136B1	136B2	Classifier name (deceased person)
136B4		Classifier name (deceased person)
136B5	136B6	Classifier divinity
136B7		Classifier creation/form
136B8		Classifier to sleep/to spend the night
136B9		Classifier statue
136BB		Classifier statue
136BD		Logogram (statue)
136BE		Classifier statue
136BF		Classifier carrying chair
136C0		Classifier divinity
136C1		Classifier statue
136C2		Logogram (monument)?
136C4		Classifier to awake
136C5		Classifier to sleep
136C6		Classifier
136C7		Classifier corpse
136C8		Classifier to sleep
136C9		Classifier (ointment vessel in the shape of the king)
136CA		Classifier wine
136CB		Logogram (to venerate)
136CC		Phonemogram/logogram (million/many)
136CD		Phonemogram
136CF		Logogram (to love)
136D0		Logogram (his townsman)
136D1	136D2	Classifier playing
136D3		Logogram (gods)
136D4		Phonemogram
136D5		Logogram (majesty)
136D6		Logogram (femine first person singular)
136D7		Classifier divinity
136D9		Classifier divinity
136DA		Phonemogram
136DB		Classifier divinity
136DC		Classifier ruler
136DE		Logogram (mistress)
136DF	136E0	Classifier personal name
136E1		Phonemogram
136E2		Logogram (Maat)
136E3		Phonemogram (in ḥw.t-ꞽr.yw (hall of records/scriptorium))
136E4		Classifier enemy
136E5		Logogram (first person singular)
136E6		Classifier youth
136E7		Phonemogram
136E8		Classifier divinity
136E9		Classifier ruler
136EA		Logogram (mistress)
136EB		Classifier divinity
136ED		Phonemogram
136EE		Classifier woman
136EF		Classifier divinity (title of šntꜣyt)
136F0		Classifier relationship
136F2		Phonemogram
136F3		Classifier name (deceased person)
136F4		spindle/spinning tool
136F6		Classifier barren woman
136F7		Classifier to mourn
136F8		Phonemogram (to form mr.ty (the two eyes))
136F9		Classifier to welcome
136FA		Classifier to praise
136FB		Classifier (mourner)
136FC		classifier divinity
136FE		Classifier fortune
136FF		Classifier to clap & phonemogram
13700	13702	Logogram (to be noble)
13703	13705	Logogram (noblewoman)
13706		Classifier name female royalty
13708	13709	Classifier personal name
1370A		Logogram (to be noble)
1370C		Logogram (to be noble)
1370D		Classifier resting
1370E		classifier youth
1370F		Classifier name
13710	13711	Classifier to welcome
13713		Classifier mourners
13714		classifier (screamers, mourners)
13715		Classifier divinity
13716		Classifier relationship
13717		Classifier to raise/to support
13718		Classifier singing
13719		Phonemogram
1371A		Logogram (to rule)
1371B		Phonemogram
1371C		Classifier mourner
1371E		Logogram (noblewoman)
1371F		Logogram (sovereign)
13720		Phonemogram
13721		Logogram (to be old, old age)
13722		Logogram (noble lady)
13723		Logogram (sovereign)
13724		Phonemogram (cryptography)
13725		Classifier mourner
13726		Classifier?
13727		Classifier danceress
13728		Classifier nursing, rearing
13729		Classifier
1372B		Classifier royal sister
1372C		Classifier royal personal name
1372F		Logogram (king of UE)
13730		Phonemogram
13732		Logogram (rejoicing)
13733		Classifier (to rejoice)
13734		Classifier jubilation
13735		Classifier sistrum player
13736		Classifier female rhythm maker
13737		Classifier birth
13738		Classifier nurse
13739		Logogram (to birth, to bring forth)
1373A	1373C	Classifier birth
1373D		Classifier nurse
1373F	13740	Logogram (nurse)
13742	13743	Classifier nursing, rearing
13744		classifier (dancer/acrobat)
13745		Phonemogram
13747		Classifier moving back and forth
13748		Phonemogram (cryptography)
13749		Logogram (in combination with \C268B)
1374A		Classifier moon
1374B		Classifier moon/light (together with Re, representing the sun and the moon as the two lights)
1374D	1374E	Logogram (Geb)
1374F		Logogram (the earthmaker (divinity))
13751	13752	Logogram (the utterance, divinity)
13753		Logogram (perception/knowledge (divinity)
13754		Logogram (perception/knowledge (divinity))
13758		Logogram (first person singular, for Harsomtus)
13759		Classifier Khepri (divinity)
1375A		Logogram (spirit)
1375B		Logogram (god)
1375C		Classifier divinity (Chay)
1375D		Classifier divinity
1375F		Classifier divinity
13760		Classifier divinity (Nekhbet)
13761		Logogram (Khepri)
13762		Classifier Khepri (divinity)
13763		Logogram (Amon)
13764		Classifier divinity
13765		Logogram (Maat and Amon)
13766	13767	Logogram (Amon)
13768		Logogram (living image of Amon)
13769		Logogram divinity
1376C		Classifier nursing, rearing
1376D		Logogram (Amon)
1376E		Classifier Wepwawet (divinity)
13770		Classifier divinity
13771		Phonemogram
13772		Classifier jubilation
13773	13774	Logogram (to drive away)
13776	13777	Logogram (to drive away)
13778		Classifier driving away
13779		Logogram (Duamutef)
1377A		Logogram (to be strong)
1377B		Logogram (sovereign)
1377C		Logogram (Anubis)
1377D		Classifier messenger
1377E		Logogram (messenger)
1377F	13780	Logogram (to drive away)
13784		Logogram (to drive away)
13785		Logogram
13786		Classifier
13788	1378A	Logogram (decease deamon)
1378B		Logogram (to drive away)
1378C		Logogram (burial)
1378D		Classifier protector
1378F		Classifier divinity (Apis)
13790		Classifier protector
13791		Phonemogram
13793		Phonemogram
13794		Logogram (Shu)
13795		Logogram (son/child of)
13796		Logogram (Horus)
13797		Classifier joy
13798		Classifier falcon divinity
13799		Classifier divinity
1379A		Logogram (majesty)
1379B		Phonemogram/logogram
1379C		Classifier divinity
1379D	1379F	Logogram (Re)
137A0		Logogram (day)
137A1	137A2	Logogram (Re)
137A4		Logogram (Re)
137A5	137A6	Logogram (Re and image)
137A7		Logogram (the eye of Re)
137A8		Logogram (of Re)
137A9		Logogram (Son of Re)
137AA		Classifier statue/likeness
137AB		Classifier divinity
137AC		Logogram (to live)
137AD		Logogram (eye of Horus)
137AE		Phonemogram/logogram (lord)
137AF		Logogram (majesty)
137B0		Logogram (spirit)
137B1		Logogram (power, strength)
137B2		Phonemogram/logogram
137B3		Logogram (god)
137B4		Logogram (Beloved of Horus)
137B5	137B6	Classifier Sokar (divinity)
137B8		Classifier Montu (divinity)
137B9		Classifier divinity
137BA		Logogram (first person singular)
137BC		Logogram (Khonsu)
137BD		Classifier Khonsu (divinity)
137BF		Logogram (the one of the horizon)
137C1		Logogram (god)
137C2		Logogram (in the ꜥnḫ-nṯr-nfr construction)
137C3		Logogram (god and goddess)
137C4		Logogram (god)
137C5		Logogram (Re)
137C6		Logogram (the one of the horizon)
137C7		Logogram (Horus, Behedety)
137C8		Logogram (Horus)
137C9		Logogram (Horus, protector of his father, Behedety, the many-coloured of plumage, giving life)
137CB		Logogram (god)
137CC		Logogram (the one of the horizon)
137CD		Logogram (Re)
137CE		Logogram (Horus of the east)
137D0		Logogram (strength, power)
137D1		Logogram (eternity)
137D2		Logogram nHH (eternity)
137D3	137D4	Logogram (eternity)
137D5		Logogram (the sole one, unique)
137D6		Classifier divinity
137D7		Logogram (lord of the two lands, when used in connection with a seth headed figure)
137D8		Classifier harpooner
137DA	137DB	Logogram (valour, strength)
137DC		Logogram (Qebehsenuef)
137DE		Phonemogram
137DF	137E0	Logogram (Wenty)
137E2		Logogram (Wenty)
137E3		Classifier divinity
137E4		Classifier harpooner
137E5		Logogram (harpooner) or Logogram (Wenty)
137E6		Logogram (Wenty)
137E7		Classifier divinity (Geb)
137E8	137EC	Logogram (million, many)
137ED		Logogram (millions of years)
137EE	137EF	Logogram (million, many)
137F0		Logogram (eternity)
137F2		Logogram (million, many)
137F3		Logogram (all eternity)
137F5	137F6	Logogram (million, many)
137F7		Logogram Heh (million, many)
137F8		Logogram (million, many)
137F9		Phonemogram
137FA		Logogram (million, many)
137FC	13803	Logogram (million, many)
13804	13805	Classifier to wean
13806		Logogram (Atum)
13808		Classifier child
13809		Logogram (first person singular)
1380A		Logogram (Horus the child)
1380B		Classifier creator
1380C	1380D	Logogram (Khnum)
1380E		Phonemogram
1380F	13811	Logogram (Khnum)
13812	13813	Classifier Khnum
13815		Logogram (Khnum)
13816	13817	Logogram (creator)
13818		Logogram (to build, to create)
13819		Logogram (to create, to form)
1381A		Logogram (to build)
1381B		Phonemogram
1381D		Logogram (messenger)
1381E		Logogram (Min)
13820		Classifier divinity
13824	13825	Logogram (the flood)
13826	13827	Logogram (the Nile/the flood)
13829		Logogram (the Nile/the flood)
1382B		Logogram (Onuris)
1382D		Logogram (Onuris)
1382E	1382F	Logogram (Orion)
13830		Classifier Osiris
13831		Logogram (Osiris)
13833		Logogram (one who belongs to Seth)
13835	13837	Classifier Osiris
13838		Logogram (Osiris)
13839		Logogram (Ptah)
1383A		Classifier Ptah
1383B		Logogram (Ptah)
1383C		Classifier divinity (Imhotep)
1383D		Logogram (Ptah)
1383E		Logogram (divine, godly)
1383F		Logogram (Ptah)
13840		Logogram (divine, godly)
13841		Logogram (Ptah)
13842		Classifier divinity
13843		Logogram (Re)
13844		Classifier King of UE
13845		Logogram (Re)
13846		Logogram (Khepri)
13847		Logogram (powerful one)
13849	1384A	Logogram (one who belongs to Seth)
1384B		Classifier misery, pain
1384E		Classifier vile one
1384F		Classifier evil one
13850		Classifier creation, form
13851		Logogram (Sobek)
13852		Classifier crocodile divinity
13853		Phonemogram (first person for sbk-šmꜥ-nfr)
13855		Logogram (the one who watches her mansions)
13856		Logogram (Sopdu)
13857	13858	Classifier guardian
13859		Classifier baboon divinity (i.e. Thot)
1385A		Logogram (Hapy)
1385B	1385C	Logogram (Tatenen)
1385D		Phonemogram
1385E		Classifier Tatenen
1385F	13860	Logogram (Tatenen)
13861	13862	Phonemogram
13863		Logogram (Tatenen)
13864		Logogram (Thot)
13865		Phonemogram
13866		Classifier Thoth
13868		Classifier moon
1386A		Classifier divinity
1386B	1386C	Phonemogram
1386D		Logogram/phonemogram (to be great)
1386F		Logogram (Thot)
13871		Logogram (Son of Re)
13872		Classifier earth-god
13873		Logogram (eternity)
13874	13875	Phonemogram
13876	13877	Classifier Anubis
13878		Classifier Renenutet
1387A		classifier (in ḥs-nb=s)
1387B		Logogram (Keket)
1387C		Classifier divinity?
1387D		Classifier Hathor
1387E		Logogram (Isis)
1387F		Classifier female divinity (Usually associated with Hathor)
13880		Logogram
13881		Logogram (powerful one)
13882		Logogram (majesty)
13883		Logogram/phonemogram (lord/lady)
13884		Logogram/phonemogram (lady)
13885		Logogram (life)
13886		Logogram/phonemogram (effective/splendid)
13888	13889	Logogram (mistress of the sistrum)
1388A		Logogram (majesty)
1388B		Classifier divinity
1388C	1388D	Logogram (rejoicing)
1388E		Classifier to nurse
1388F		Logogram (to nurse, to rear (from rnn))
13890		Logogram (Hathor)
13891		Logogram (gold)
13892		Logogram (ruler)
13893		Logogram (the heavens/sky)
13894		Classifier Hathor
13895		Logogram (Hathor)
13896	13897	Logogram (Isis)
13899		Logogram (Isis)
1389B		Classifier divinity
1389C		Logogram (Hathor)
1389D		Logogram (Isis)
1389E		Classifier Isis
1389F		Logogram (Isis)
138A0		Classifier divinity
138A1		Classifier mourner
138A5	138A6	Logogram (Isis)
138A7		Logogram (the widow)
138A8		Logogram (Isis)
138A9		Logogram (lord)
138AA	138AB	Logogram (to protect)
138AC		Phonemogram
138AD		Logogram/phonemogram (lady)
138AE		Classifier leonid divinity (female)
138AF		Logogram (Sekhmet)
138B0		Classifie leonid divinity (female)
138B2		Classifier leonid divinity (male)
138B4		Classifier leonid divinity (male)
138B6	138B7	Classifier leonid divinity (female)
138B8		Logogram (city, village)
138B9		Logogram (Sekhmet)
138BA	138BB	Classifier leonid divinity (female)
138BE		Logogram (she who is on the throne/stairs (Bastet))
138BF		Logogram (to be hidden)
138C0		Classifier hidden
138C1		Logogram (to be hidden)
138C2		Classifier divinity?
138C3	138C4	Classifier leonid divinity (female)
138C5		Logogram (vocative interjection)
138C6		Logogram (daughter of Re)
138C7		Phonemogram
138C8		Logogram (Maat)
138C9		Logogram (ruler of truth/Maat)
138CA		Logogram (truth)
138CB		Logogram (in name Ramses IV)
138CC		Classifier woman
138CD		Logogram (Maat)
138CE		Classifier divinity
138CF		Classifier truth
138D0		Logogram/phonemogram  (whom truth/Maat loves)
138D1		Logogram (Maat)
138D2	138D4	Logogram (in name Ramses II)
138D5		Logogram (Gate which gives truth)
138D6		Logogram (to be hidden)
138D7		Logogram (Meret)
138D8	138D9	Classifier divinity
138DA		Classifier divinity/musician
138DC		Logogram (Meret)
138DD		Classifier divinity
138DE		Logogram (Mut)
138DF		Logogram (together with \C98 and \C43A, representing the triad of Dendera)
138E0		Classifier majesty
138E1		Logogram (Mut)
138E2		Logogram (Hathor)
138E3		Logogram (Hathor, giving life)
138E4		Logogram (Hathor)
138E5		Phonemogram
138E6		Classifier divinity
138E7		Phonemogram
138E8	138E9	Logogram (Neith)
138EA		(cryptography) Phonemogram
138EB		Phonemogram
138EC		Logogram (king of LE)
138ED		Phonemogram
138EE		Classifier divinity (Neith)
138EF		Phonemogram
138F0		Logogram (Dendera)
138F1		Logogram (Nephthys)
138F2		Classifier sister (together with Isis)
138F3		Classifier mourner
138F4		Logogram (Nephthys)
138F5	138F6	Logogram (the heavens/sky)
138F7		Phonemogram
138F8		Logogram (the heavens/sky)
138F9		Logogram (hour)
138FA	138FB	Logogram (city, village)
138FC		Logogram (the sky)
138FD		Logogram (the heavens/sky)
138FE		Logogram/phonemogram (to shine)
138FF		Classifier divinity (Sothis)
13900		Logogram (Seshat)
13902	13903	Logogram (Seshat)
13904		Logogram (stretching the rope)
13905		Phonemogram
13907		Classifier Bovid divinity
13908		Logogram/phonemogram (lord)
13909		Logogram (the throne (Edfu))
1390A	1390C	Logogram (sovereign)
1390D		Logogram (ruler)
1390E		Logogram (sovereign)
1390F		Logogram (ruler)
13910	13914	Phonemogram
13915		Classifier divinity
13916		Logogram
13917		Classifier divinity
13918		Classifier Hekat
13919		Logogram (Keku)
1391A		Logogram (the west)
1391B		Logogram (Serqet)
1391C		Logogram (Thebes)
1391D		Phonemogram
1391E		Logogram (moon)?
1391F		Classifier (Sekhet, goddes of the marshlands)
13920	13921	Classifier divinity
13922		Logogram (perception/knowledge)
13923		Logogram (morning)
13925	13928	Logogram (morning)
13929		Logogram (the two of the horizon)
1392A		Logogram (the (four) supports)
1392B	1392C	Logogram (Hathor)
1392D		Classifier female
1392E		Logogram (head)
1392F		Classifier to laugh
13930		Classifier spit
13931		Classifier birthplace
13932		Logogram (Hathor)
13933		Classifier staff
13934		Phonemogram
13935	13936	Logogram (face)
13937		Classifier human being
13938		Classifier occupation
13939	1393A	Classifier calling
1393D		Classifier eating
1393E		Classifier child
1393F		Classifier child/small one
13940		Classifier nursing
13941		Classifier dwarf/pigmy
13942		Classsifier (to bow, to attack)
13943		Classifier to fall
13944		Classifier to call
13945		Classifier to rejoice
13946		classifier turning around
13948		Classifier to rejoice
13949		Logogram (Heh, divinity)
1394A		Classifier upside down
1394B		Classifier to swim
1394D		Classifier swimming
1394F		Logogram (to be great)
13950		Classifier herald
13951		Classifier to carry away, to take
13952		Classifier herald
13954		Classifier elder/official
13955		Classifier Orion
13956		Classifier to spit, to spew
13957		Classifier to lift, to carry
13958		Classifier to drive away
13959		Classifier to oppose, to rebel
1395A		Classifier to extend
1395B		Classifier to scatter
1395D		Classifier dancing
1395E		Classifier guarding, protecting
1395F		Classifier drinking
13960		Classifier to uproot
13962		Classifier to churn up
13963		Classifier breaking/destroying
13964		Classifier to expel, to drive of
13965		Classifier potter
13966		Classifier to climb, to fly
13967		Classifier (to melt, to cast)
13969		Classifier to drive away
1396A		Logogram (lifetime)
1396B		Logogram (evil one)
1396D		Logogram (evil one)
1396E	1396F	Classifier tresses
13970		Logogram (head covering (braid of hair?))
13971		Classifier scalp, temple
13972		Classifier hairlock
13973		Logogram (to see)
13974		Classifier eye-paint
13975		Phonemogram
13976	13979	Classifier eye related actions
1397A		Logogram (to see, to behold)
1397B		Phonemogram
1397C		Classifier sleep
1397D		Phonemogram
1397E		Classifier adornment/beauty
1397F		Classifier (to sleep)
13980		Classifier eye related actions
13982		Phonemogram
13984		Phonemogram
13985		Logogram (to wake)
13986		Logogram (to weep)
13987		Classifier weeping/crying
13988		Phonemogram
13989		Logogram (to weep)
1398A		Classifier weeping/crying
1398B		Classifier eye related actions
1398C		Logogram (The dazzling eye (=Egypt))
1398D		Logogram (eye)
1398E		Logogram (the eye of Re)
1398F		Logogram (to see)
13990		Classifier backside
13991		Classifier nose
13992		Classifier to suckle
13994		Logogram 1/3
13995		Logogram (2/3)
13996		Interpretant
13997		Logogram (lip, border, edge)
13998		Logogram (lips)
13999		Classifier spit
1399A		Logogram (breakfast (washing the mouth))
1399B		Classifier spit
1399C	1399D	Phonemogram
1399E		Classifier beard or Classifier hair
1399F		Logogram (to sit)
139A0		Logogram (spirit, essence)
139A2		Logogram (spirit, essence)
139A3		Logogram (royal spirit/essence)
139A4	139A5	Logogram (food, provisions)
139A6		Logogram (negative relative adjective)
139A7		Phonemogram
139A9		Phono-repeater
139AA		Phono-repeater (kidney)
139AB		Classifier to embrace
139AC		Logogram (to embrace)
139AD		Classifier (in ẖꜣm-(ꞽ)ḫ.t)
139AE		Logogram (mortuary priest)
139B0		Logogram (to row, to convey by water)
139B1		Classifier movement by boat
139B2		Logogram (to row, to convey by water)
139B3		Phonemogram
139B4		Classifier grasping the oar
139B5	139B6	Phonemogram
139B7	139BA	Logogram (to fight)
139BC		Logogram (to fight) (in ꜥḥꜣ.t (fighter (female))
139BE		Logogram (to fight) (in ꜥḥꜣ.t (fighter (female))
139BF	139C1	Logogram (to fight)
139C2		Logogram (negative particle)
139C3		Classifier arm related movements or actions
139C4		Logogram (arm, hand)
139C5	139C6	Phonemogram
139C7		Classifier supporting/carrying
139C8		Classifier enveloping
139C9		Logogram (arm, shoulder)
139CA		Classifier shoulder/arm
139CB		Logogram (to offer, to present) or Phonemogram
139CC		Phonemogram
139CD		Logogram (to receive)
139CE	139CF	Logogram (course (of the day), daily requirements)
139D0		Classifier strength, power
139D1		Logogram (offering Maat)
139D3		Classifier force, effort
139D5	139D7	Logogram (to wash)
139DA		Phonemogram
139DB		Classifier washing
139DC		Logogram (to wash)
139DD		Classifier stretching out
139DE		Classifier negative action
139DF		Classifier to rejoice
139E0		Classifier to call
139E1		Logogram (to protect)
139E2		Logogram (to make holy)
139E6		Classifier to govern/to control
139E7		Classifier messenger
139E8		Logogram (to make holy, to be holy, to be splendid)
139E9		Phonemogram
139EA		Classifier netherworld
139EB		Phonemogram
139EC		Classifier to write, to inscribe
139ED		Logogram (to write, to inscribe)
139EE		Classifier to destroy, to overthrow
139EF		Classifier elder/official
139F0		Classifier adoration
139F1		Logogram (to make holy)
139F2		Logogram (to make holy/to be sacred)
139F3		Phonemogram
139F4		Logogram (to repel)
139F5		Logogram (to make holy/to be sacred)
139F6		Classifier fighting
139F7		Phonemogram
139F8		Logogram (scent, perfume, dew)
139F9	139FA	Phonemogram
139FB		Logogram (scent, perfume, dew)
139FC		Classifier cut of hand
139FD		?
139FE		Phonemogram
139FF		Phono-repeater
13A00		Classifier
13A01		Classifier to hold fast/to seize
13A02		Logogram (to seize, to grasp)
13A03		Classifier to squeeze, to enclose, to tie up
13A04		Classifier
13A05		Phono-repeater
13A06		Logogram (Prospopite nome)
13A07		Classifier copulating
13A08		Phonemogram
13A09		Classifier copulation
13A0A		Logogram (the two testicles)
13A0B	13A0C	Classifier testicles
13A0D		Logogram/Phonemogram (cow)
13A0F	13A11	Phonemogram
13A12		Classifier to run
13A13		Classifier to fall
13A14		Classifier turning back
13A15		Classifier to spread
13A16		Classifier to be upside down
13A17		Interpretant r and classifier movement
13A18		Phonemogram (dental) and classifier movement
13A19		Phonemogram
13A1A		Logogram (to transgress)
13A1B		Classifier to disappear
13A1C		Logogram (transgression)
13A1D	13A1F	Logogram (to be pure, to be clean)
13A20	13A21	Phonemogram
13A22		Phonemogram (Orion)
13A23	13A24	Phonemogram
13A26	13A28	Phonemogram
13A29		Logogram (Orion)
13A2A		Phonemogram
13A2B		Phonemogram/logogram (annals)
13A2D		Phonemogram
13A2F		Phonemogram
13A32		Classifier throat
13A33		Classifier cheeks/eyebrows
13A34		Classifier throat
13A35		Classifier pupil
13A36		Classifier taking/carrying
13A37		Classifier violent one
13A38		Classifier enemy
13A39		Classifier rage, anger
13A3B		Logogram (Seth)
13A3C		Classifier Seth
13A3D		Classifier fighting
13A3E		Logogram (Seth)
13A3F	13A40	Classifier Seth
13A41		Logogram (Seth)
13A42	13A43	Classifier Seth
13A44		Logogram (11th nome of Upper Egypt)
13A45		Classifier Seth
13A47		Logogram (Seth)
13A49		Logogram (Seth)
13A4C		Logogram (Seth)
13A4E		Logogram/Phonemogram (lord, in nb.ty, the two lords Horus and Seth)
13A4F		Logogram/Phonemogram (lord, in nb.wy, the two lords Horus and Seth)
13A50		Logogram (Seth)
13A54		Logogram (Seth)
13A55	13A56	Classifier storm
13A57		Logogram/Phonemogram (lord, in nb.wy, the two lords Horus and Seth)
13A58	13A59	Classifier storm, storm cloud
13A5A		Logogram/Phonemogram (Hebenu, capital of the 16th nome of Upper Egypt)
13A5B	13A5C	Logogram (Oryx nome, 16th nome of Upper Egypt)
13A5D		Logogram (Oryx nome, 16th nome of Upper Egypt
13A5E		Classifier oryx
13A5F	13A60	Phonemogram
13A62		Classifier (Oryx)
13A63		Classifier roarer
13A64		Logogram (herd, flock)
13A65		Classifier noble/dignity/rank
13A66		Logogram (gazelle)
13A67		Phonemogram
13A68		Logogram (rams)
13A69		Logogram (Son of Re)
13A6A		Logogram (he of Edfu)
13A6B		Phonemogram (in bꜣ-n-rꜥ-mr.y-ꞽmn)
13A6C	13A6D	Phonemogram
13A6E		Logogram (to the north of)
13A70		Classifier ram divinity
13A71	13A72	Phonemogram
13A74		?
13A75	13A77	Phonemogram
13A78		Logogram/Phonemogram (to make glad, to be glad)
13A7A	13A7B	Phonemogram
13A7C		Classifier jackal
13A7D		Phonemogram/logogram (those that conduct)
13A7E		Phonemogram
13A7F		Phonemogram/logogram (many-coloured of plumage)
13A80		Logogram (jackal of Upper Egypt)
13A81		Logogram (Wepwawet of Upper Egypt)
13A83		Phonemogram
13A84		Logogram (Wepwawet)?
13A85		Logogram (those who conduct the bark of Re)
13A86		Phonemogram
13A87		Logogram ((secret) image (of a god))
13A88		Logogram (to make secret)
13A89		Logogram (the primary (secret) image (of a god))
13A8A		Logogram ((secret) image (of a god))
13A8B		Classifier divinity
13A8C	13A8E	Logogram (Anubis)
13A8F		Classifier canine divinity
13A91	13A93	Classifier canine divinity
13A94	13A95	Logogram (Anubis nome (17th nome of Upper Egypt))
13A97		Logogram (privy to the secrets)
13A98		Logogram (Anubis)
13A99		Logogram (cat)
13A9A		Logogram (like Re)
13A9B		Phonemogram
13A9C		Logogram (given life like Re)
13A9E		Logogram (young lioness)
13A9F	13AA2	Phonemogram
13AA4		Phonemogram
13AA5	13AA6	Classifier horse
13AA7	13AA8	Logogram (span (of horses)/horse)
13AAA		Classifier cattle
13AAB		Logogram (rank, diginity)
13AAE		Logogram (griffin)
13AAF		Classifier griffin
13AB0		Logogram (triomphator)
13AB1		Classifier hippopotamus goddess
13AB3		Classifier hippopotamus
13AB4		Classifier animal in water
13AB5		Logogram/phonemogram (Ipet)
13AB6		Phonemogram/logogram (in ꞽp.t-sw.t)
13AB7	13AB8	Logogram/Phonemogram (great one (female))
13AB9		Logogram (to rejoice)
13ABA		Logogram (first person signular, referring to Nut)
13ABB		Classifier jackal
13ABD	13ABE	Phonemogram
13ABF		Logogram (Hermopolis magna, 15th nome of UE)
13AC1		Logogram (lord of the two lands)
13AC2		Classifier (lion)
13AC3		Logogram (lion)
13AC4		Phonemogram
13AC5		Classifier divinity (lioness)
13AC7		Logogram (throne dais)
13AC8		Logogram (lion)
13ACA	13ACB	Logogram (living lion)
13ACC	13ACE	Phonemogram
13ACF		Logogram (to present)
13AD0		Logogram/phonemogram (King of UE and LE, lord)
13AD1		Logogram (in the construction sꜣ-rꜥ nb ḫꜥ.w)
13AD2		Logogram (Mehyt, divinity)
13AD3		Logogram (Pachet)
13AD4		Phonemogram tf and phonemogram r
13AD5		Phonemogram
13AD6		Classifier divinity
13AD7		Logogram (to give, to place)
13AD8	13AD9	Phonemogram
13ADA		Phonemogram (in ꜣwtwkrtr)
13ADB		Logogram (Re)
13ADD		Logogram (Matit, Goddess of 12th nome of Upper Egypt)
13ADE		Logogram (door-bolt)
13ADF		Logogram (every day)
13AE0		Logogram (Pachet)
13AE1	13AE2	Phonemogram
13AE3		Logogram (to make holy)
13AE4		Classifier aggressive like a lion
13AE5		Classifier leopard
13AE6		Phonemogram/logogram (rage, anger)
13AE7		Logogram (Tefrer, geographical location)
13AE8	13AE9	Logogram (Thot)
13AEA		Logogram (King (of UE))
13AEB	13AEC	Phonemogram
13AED		Logogram (scribe)
13AEE		Logogram (to write, to inscribe)
13AEF		Logogram (new years day)
13AF0		Logogram (to speak words, to recite)
13AF1		Logogram (recitation by)
13AF4	13AF5	Phonemogram
13AF7		Classifier ritual object
13AF8	13AF9	Logogram (symbol of the cycle of time)
13AFA	13AFB	Phonemogram
13AFE		Logogram (lady of writing)
13AFF		Phonemogram
13B00	13B01	Logogram (to be good)
13B02		Classifier baboon
13B03		Phonemogram
13B05		Classifier monkey
13B07		Logogram/phonemogram (beautiful of face)
13B08		Logogram (good year)
13B0A		Logogram (new years day)
13B0B	13B0E	Phonemogram
13B0F		Logogram/phonemogram (the beautiful lotus flower)
13B11		Phonemogram
13B12		Logogram (to adorn) or Logogram (to be friendly)
13B13		?
13B14		Classifier mouse
13B15	13B16	Logogram (lord)
13B17		Logogram rꜥ and nb (in sꜣ-rꜥ nb ḫꜥ.w)
13B18		Logogram (King of UE and LE, lord)
13B19		Logogram (lord of the two lands)
13B1A	13B1B	Logogram (living image)
13B1C	13B1D	Logogram (the sole/unique lord)
13B1E		Logogram (lord)
13B20		Phonemogram
13B21		Logogram (lord)
13B22		Logogram (presenting myrrh)
13B23		Logogram (image, refering to the king)
13B25		Logogram (image)
13B26		Logogram (lord)
13B27	13B28	Classifier Divinity Aker
13B2B		Classifier Hapy
13B2C		Phonemogram
13B2D		Logogram (yoke of oxen)
13B2E		Phonemogram
13B2F		Classifier bull (specifically in kꜣ-ḥḏ (the (sacred) white bull)
13B30		Classifier bovid (steer, ox, cattle, male animal)
13B31		Classifier glad, pleased
13B32		Classifier bovid (steer, ox, cattle, male animal)
13B33		Logogram (cow)
13B34		Logogram (bull)
13B35	13B36	Logogram (sacrificial steer)
13B37		Classifier (Seth)
13B38		Logogram (sacrificial steer)
13B39		Classifier (to fall)
13B3B		Classifier slaughter?
13B3C		Classifier prepare to attack
13B3E		Logogram (11th nome of LE)
13B3F	13B40	Logogram (6th nome of LE)
13B41		Logogram (Cynopolis nome)
13B42		Logogram (12th nome of LE)
13B43		Classifier divinity
13B44		Phonemogram (in ꜣms-ꞽb (to rejoice))
13B45		Phonemogram
13B46		Classifier cow divinity
13B47		Phonemogram (in ꜣms-ꞽb)
13B48		Phonemogram
13B49		Logogram (lady)
13B4A		Logogram (Re and lord (in sꜣ-rꜥ nb ḫꜥ.w))
13B4C		Logogram (cattle)
13B4D		Logogram (King of UE and LE, lord)
13B4E		Classifier cow divinity
13B4F		Logogram (Re and lord (in sꜣ-rꜥ nb ḫꜥ.w))
13B50	13B51	Classifier cow divinity
13B53		Phonemogram (in km-wr)
13B54		Logogram (10th nome of LE)
13B56		Logogram (12th nome of LE)
13B57		Classifier (bull)
13B58		Logogram (bull, beef)
13B59		classifier divinity (Ash-spitter)
13B5A		Classifier Ammet
13B5B		Classifier rhinoceros
13B5C	13B5D	Phonemogram
13B5F		Phonemogram
13B60		Logogram (worth, dignity, renown)
13B61		Classifier ram
13B62	13B63	Classifier worth, dignity, renown
13B64		Logogram (worth, dignity, renown)
13B65		Classifier (atef crown)
13B66	13B67	Logogram (worth, dignity, renown)
13B68		Classifier worth, dignity, renown
13B69		Logogram (the eight primordial gods)
13B6A		Logogram (bull)
13B6B		Phonemogram
13B6C		Classifier rage/aggression
13B6D		Phonemogram
13B6E		Logogram (bull)
13B6F		Classifier
13B70		Classifier Ursa Major constelation
13B71		Logogram (bull)
13B72		Classifier nose
13B73		Classifier kissing
13B74		Classifier double doors
13B75		Logogram (double doors)
13B76	13B79	Phonemogram
13B7B	13B7C	Phonemogram
13B7D		Logogram (jackal)
13B7F		Logogram (Ennead)
13B81		Phonemogram
13B82	13B83	Logogram (throat)
13B85	13B86	Phonemogram
13B87		Logogram (gazelle)
13B88	13B89	Phonemogram
13B8A		Logogram (antilope)
13B8B		Phonemogram
13B8C		Logogram (ibex)
13B8E	13B90	Phonemogram
13B91		Logogram (to distinguish) and  (beginning, front)
13B92		Logogram (beginning, front)
13B93		Classifier Haker festival
13B94		Logogram (Khonsu)
13B95		Classifier strength
13B97	13B98	Phonemogram
13B9A	13B9D	Phonemogram
13B9F		Phonemogram
13BA0		Phono-repeater
13BA1		Phonemogram
13BA2		Classifier hyena
13BA3		Logogram (rage)
13BA4	13BA5	Logogram (new years day)
13BA6		Phonemogram (commonly in wp-rnp.t)
13BA9		Logogram (the one who awakes whole)
13BAA	13BAB	Phonemogram
13BAE		Logogram (to be true)
13BB2		Classifier jaw
13BB3	13BB5	Phonemogram
13BB6		Logogram to hear, to listen
13BB7		Logogram (magic)
13BB8		Phonemogram
13BB9		Classifier thigh
13BBC		Phonemogram
13BBD		Logogram (to repeat)
13BBE	13BC0	Phonemogram
13BC2	13BC3	Phonemogram
13BC4		Logogram (Letopolis)
13BC5	13BC6	Phonemogram
13BC7		Classifier animal
13BC8		Phonemogram
13BC9		Classifier animal
13BCA		Classifier leopard skin
13BCB		Classifier hoof
13BCC	13BD1	Phonemogram
13BD2		Logogram (skin, water skin)
13BD3		Phonemogram
13BD4		Classifier back/end
13BD5		Phonemogram
13BD6		Phono-repeater
13BD7	13BD8	Phonemogram
13BDA	13BE1	Phonemogram
13BE2		Logogram (who unites the two lands)
13BE3		Classifier (backbone)
13BE4	13BE5	Classifier back, backbone
13BE6		Classifier cutting/slaughter
13BE7		Phono-repeater
13BE8		Classifier cutting
13BE9		Classifier shreds, pieces
13BEA		Phono-repeater
13BEB	13BEC	Phonemogram
13BEE	13BEF	Logogram (to be long, to stretch out)
13BF0		Classifier rib (offering)
13BF1	13BF2	Logogram (slaughter, evil)
13BF3		Classifier rib (offering)
13BF5		Logogram (to bring, present, offer, go)
13BF6		Phonemogram and classifier movement (in thm (to tread, to penetrate))
13BF7		Phono-repeater
13BF8		Classifier meat
13BFA		Classifier offering meat
13BFB		Phonemogram
13BFC		Logogram (limb)
13BFD		Phonemogram
13BFE		Phonemogram (in m-pẖr)
13BFF	13C00	Logogram (to go round, to turn round)
13C01	13C02	Classifier scent
13C03		Phonemogram
13C04		Phonemogram or Classifier enemy
13C05		Classifier liver
13C07		Classifier (talons or fangs)
13C08		Classifier spine
13C09	13C0A	Phonemogram
13C0B		Logogram (ostrich)
13C0E		Logogram (to tremble
13C0F		Classifier to tremble
13C10		Phonemogram (like in ḫsbd lapis-lazuli)
13C11		Logogram (soul)
13C13		Phono-repeater
13C14		Phonemogram
13C15		Logogram (Sepa)
13C16		Phonemogram
13C17		Logogram (to tremble)
13C18		Phonemogram
13C19		Logogram (to destroy)
13C1A		Classifier
13C1B	13C1D	Phonemogram
13C1F	13C23	Phonemogram
13C25		Phonemogram
13C27		Phonemogram
13C28		Phono-repeater
13C29		Phonemogram
13C2A		Classifier lying, sleeping, spending the night
13C2B		Phonemogram
13C2D	13C2F	Phonemogram
13C30		Phonemogram/phono-repeater
13C31		Phonemogram
13C33	13C34	Phonemogram
13C36		Phonemogram
13C37	13C38	Logogram (soul)
13C3A		Logogram (might, power)
13C3C		Logogram (to hack up, to open up (the earth))
13C40		Phonemogram
13C43		Phonemogram
13C45	13C46	Phonemogram
13C47		Classifier bird offering
13C48		Classifier destroy, to destroy (in this case specifically in ḥtm.yt, place of execution)
13C49		Logogram (bird, fowl)
13C4A		Phonemogram
13C4B		Logogram (might, power)
13C4C		Logogram/phonemogram (in ḥw.t-bꜣ.w (room in the Esna temple))
13C4D		Phonemogram
13C4E	13C50	Logogram (god)
13C51		Logogram (to inundate)
13C52		Logogram (soul)
13C54	13C55	Logogram (to inundate)
13C56		Logogram (inundation)
13C57		Logogram (god)
13C58		Phonemogram
13C59		Classifier heron
13C5A	13C5B	Phonemogram
13C5C		Logogram (god)
13C5D		Logogram (Thot)
13C5E		Logogram (to be excellent)
13C5F		Logogram (Thot)
13C60		Logogram (god)
13C62	13C63	Logogram (Thot)
13C64		Logogram (god)
13C65		Logogram (Thot)
13C66		Phonemogram
13C67	13C68	Logogram (god)
13C69		Classifier Thot
13C6A		Logogram (god)
13C6C		Logogram (Horus)
13C6D	13C6F	Logogram (Re-Hor (usually in rꜥ-ḥr-ꜣḫ.ty)
13C70	13C72	Logogram (Horus)
13C73		Classifier king
13C74	13C75	Phonemogram
13C76		Classifier divinity
13C77		Logogram (Sopdu (divinity))
13C78		Logogram (the female Horus)
13C79		Logogram (Horus)
13C7A		Logogram (the female falcon)
13C7B		Logogram (goddess)
13C7C		Logogram (god)
13C7D		Logogram (high quality (red) linen)
13C7F		Logogram (west)
13C80		Logogram (West, 3rd nome of LE)
13C81		Logogram (high quality (red) linen)
13C82		Classifier divine beings/divine things
13C83	13C84	Logogram (goddess)
13C85		Classifier divinity (Min)
13C86		Logogram (May he live, the god)
13C87	13C88	Logogram (majesty)
13C8A	13C8B	Logogram (Harsomtus)
13C8C		Logogram (The two gods, 5th nome of UE)
13C8D	13C8F	Logogram (Throne of Horus (Edfu))
13C90		Logogram (Throne of Horus (Edfu, 2nd nome of UE))
13C91		Logogram (Horus who is on the palace façade)
13C92		Logogram/phonemogram (Horus, who endures on the palace façade)
13C93		Classifier the one who is on the palace façade
13C94		Logogram (The living falcon who is on the palace façade)
13C95		Logogram (throne, palace façade)
13C96	13C97	Logogram (west, right side)
13C98	13C99	Logogram (necropolis)
13C9B	13C9C	Logogram (Nemty (divinity))
13C9D	13C9F	Logogram (lord)
13CA0		Classifier (Sokar)
13CA1		Phonemogram
13CA2		Logogram
13CA3		Logogram (sanctuary of Sokar)
13CA4		Logogram (lord)
13CA5		Logogram (in bꞽk-n-nbw.t, falcon of the golden ones)
13CA6		Logogram (golden Horus)
13CA7		Logogram (Nemty (divinity))
13CAA		Classifier high quality (red) linen
13CAB	13CAC	Logogram (high quality (red) linen)
13CAD		Logogram (the one who spreads out his wings ((Dewen-anwy) divinity))
13CAF		Phonemogram
13CB0		Phonemogram and classifier throne (in ṯnṯꜣ.t)
13CB2	13CB5	Logogram (many-coloured of plumage)
13CB6	13CB8	Logogram (many-coloured of plumage, who goes forth in/from the horizon)
13CBA		Logogram (to protect)
13CBC		Logogram (the one who spreads out his wings ((Dewen-anwy) divinity))
13CBE		Logogram (to protect)
13CBF		Classifier falcon
13CC0		Classifier falcon/bird of prey
13CC1	13CC2	Logogram (god)
13CC3		Logogram (Horus)
13CC4		Classifier cult image
13CC5		Logogram (Horus)
13CC6	13CC8	Logogram (Haroeris)
13CC9		Logogram (Sopdu (divinity))
13CCA		Classifier cult image
13CCC		Logogram
13CCF		Classifier (some type of bird) or (Dedwen, divinity)
13CD0		Phonemogram
13CD1		Classifier negative, bad
13CD3		Phonemogram
13CD4		Logogram (brick, sheet, ingot)
13CD5	13CD6	Logogram (soul)
13CD9		Phonemogram
13CDA		Logogram (He of Edfu)
13CDC		Logogram (the female falcon)
13CDD		Logogram (goddess)
13CDE		Logogram (soul)
13CE0		Classifier descendant
13CE1		Phonemogram
13CE2		Logogram (water fowl)
13CE3		Classifier nest
13CE5		Classifier nest
13CE6	13CE7	Phonemogram
13CE9	13CEA	Phonemogram
13CEB		Logogram (nest)
13CEC		Phonemogram
13CED		Logogram (bird-pool, nest)
13CEE		Logogram (nest)
13CEF		Logogram (bird-pool, nest, marshland)
13CF0		Classifier pelican
13CF1	13CF6	Phonemogram
13CF7	13CF8	Logogram (common folk, subjects, people)
13CF9		Phonemogram/Logogram (who everyone knows)
13CFA	13CFB	Logogram (common folk, subjects, people)
13CFC		Phonemogram
13CFE		Phonemogram
13D00		Phonemogram
13D02		Logogram (goddess)
13D03		Logogram (Nekhbet (divinity))
13D04		Classifier divinity  (Nekhbet)
13D05		Logogram (Mut (divinity))
13D06		Classifier uraeus
13D07		Logogram (lady (in nb.ty))
13D08		Logogram (new year festival)
13D09	13D0B	Logogram/phonemogram (to protect)
13D0E		Phonemogram
13D0F		Logogram (mother of the god, lady of)
13D10		Logogram (staff)
13D11	13D13	Classifier staff
13D14		Phonemogram
13D15		Logogram (staff)
13D16		Phonemogram/logogram (end)
13D17		Logogram (to see)
13D18		Phono-repeater
13D19		Logogram (to speak, to say)
13D1A		Classifier common crane
13D1B		Logogram (to speak, to say)
13D1C	13D1D	Phonemogram
13D1E		Phonemogram/logogram (spirits)
13D1F		Phono-repeater
13D23	13D24	Phonemogram
13D25		Classifier double feather
13D26		Phonemogram
13D28		Logogram (claw, talon)
13D29		Logogram (one who is within an egg)
13D2A		Logogram (Duau (divinity))
13D2B	13D2E	Phonemogram
13D2F		Logogram (Nehebkau (divinity))
13D30		Classifier hardun lizard
13D31		Classifier evil
13D32		Classifier Nun
13D33		Logogram (Sobek (divinity))
13D34		Logogram (Iqer, 6th nome of UE)
13D35		Classifier divinity (Sobek)
13D36		Logogram (Iqer, 6th nome of UE)
13D37		Logogram (Medinet Habu)
13D38		Logogram (Iqer, 6th nome of UE)
13D39		Classifier water animal
13D3A		Classifier enemy in crocodile form
13D3B		Logogram (crocodile)
13D3C	13D3D	Classifier enemy in crocodile form
13D3E		Classifier crocodile
13D3F		Logogram (crocodile)
13D40		Logogram (Sobek (divinity))
13D41		Logogram (to gather)
13D42		Logogram (Sobek (divinity))
13D43		Logogram (Sobek-Re (divinity))
13D44		Logogram (sovereign)
13D45		Logogram (Sobek (divinity))
13D46		Phonemogram
13D47		?
13D48		Logogram (Sobek-Re (divinity))
13D49		Classifier the two crocodiles
13D4A		Logogram (moment of attack)
13D4B		Logogram (Egypt)
13D4C	13D4E	Phonemogram
13D51		Logogram Hfn (one hundred thousand)
13D52		Logogram (Heqet (divinity))
13D53		Logogram (one hundred thousand)
13D54		Classifier snake
13D55	13D56	Logogram (to enter)
13D57	13D58	Logogram (to go forth)
13D59		Classifier snake
13D5A		Logogram (lifetime)
13D5B	13D5D	Phonemogram
13D5E		Logogram (father)
13D5F		Phonemogram
13D61		Phonemogram/logogram (his name)
13D62		Logogram (to go forth)
13D63		Phonemogram
13D64		Logogram (to go forth)
13D65		Logogram (divinity)
13D67		Phonemogram/logogram (eternity)
13D68		Logogram (eternity)
13D69		Classifier divinity
13D6A		Logogram/phonemogram (boundry, cliff)
13D6B		Logogram (boundry, cliff)
13D6C		Classifier divinity
13D6D	13D6E	Logogram (the two mountain ranges of the Nile valley)
13D6F		Logogram (eternity)
13D70	13D71	Phonemogram
13D72		Phonemogram (in ḥḏ-tꜣ, dawn, daybreak)
13D73	13D77	Logogram (cavern)
13D78		Logogram (the two holes, the two caverns)
13D79		Classifier female divinity
13D7A		Logogram (lady (in nb.ty))
13D7B	13D7C	Logogram (fire, flame)
13D7D		Classifier the two Udjat eyes
13D7E		Logogram (goddesses)
13D7F		Classifier Ennead
13D82	13D84	Logogram (goddess)
13D87		Logogram (goddesses)
13D88		Classifier uraeus snake
13D89		Logogram (lady (in nb.ty))
13D8A		Phonemogram
13D8B		Logogram (lady (in nb.ty))
13D8C		Classifier the two uraeus snakes
13D8D		Logogram (Hathor)
13D8E		Logogram (goddess)
13D8F		Logogram (Renenoutet)
13D90		Phonemogram/logogram (to encircle with)
13D91		Classifier snake, uraeus
13D92		Logogram (Wadjet (divinity)
13D93		Logogram (lady (in nb.ty))
13D94		Classifier uraeus
13D95		Logogram (lady (in nb.ty))
13D96		Logogram (Renenoutet)
13D97		Logogram (uraeus)
13D98		Classifier coil (of a snake)
13D99	13D9B	Logogram (uraeus)
13D9D		Logogram (uraeus)
13DA0	13DA1	Logogram (lady of Dendera)
13DA2	13DA3	Phonemogram/logogram (to not know)
13DA4		Phono-repeater
13DA5		Phonemogram/logogram (to not know)
13DA7		Logogram (Renenoutet)
13DA8	13DA9	Phonemogram
13DAA		Logogram (the two caverns)
13DAB		Classifier snake
13DAD		Classifier snake
13DAE		Phonemogram
13DAF		Classifier snake, serpent
13DB1	13DB2	Phonemogram
13DB3		Phonemogram n and logogram bꜣ (soul)
13DB4		Classifier snake
13DB6		Phonemogram
13DB7		Logogram (Shai (divinity))
13DB8	13DB9	Classifier snake, serpent
13DBB	13DBC	Classifier snake
13DBD		Classifier snake/enemy
13DBE	13DBF	Classifier snake/enemy (Apophis)
13DC0		Classifier snake
13DC1		Classifier snake/enemy (Apophis)
13DC3		Classifier snake/enemy (Apophis)
13DC4		Classifier snake/divinity
13DCA		Logogram (the north wind)
13DCB		Phonemogram rr and classifier geographical location
13DCC		Logogram (fish)
13DCD		Phonemogram
13DCE		Logogram (canal of the two fishes (in the second nome of UE))
13DCF		Phonemogram
13DD0		Phonemogram/logogram (Shenes (geographical location))
13DD1		Logogram (Re)
13DD2	13DD3	Phonemogram
13DD4		Logogram (First-of-fishes nome (16th nome of LE))
13DD5		Phonemogram
13DD6	13DD9	Logogram/phonemogram (to flood out, to emerge)
13DDA		Phonemogram
13DDC		Logogram (anger, discontent)
13DDD		Logogram (to be angry)
13DDF		Logogram (to be angry)
13DE1		Logogram (to become)
13DE2		Logogram/Phonemogram (life to)
13DE3		Logogram (to illuminate)
13DE4		Classifier winged scarab
13DE5	13DE7	Logogram (to go forth)
13DE9		Logogram (who goes forth from the horizon)
13DEA		Logogram (the winged scarab)
13DEB		Logogram (scarab (amulet))
13DEC		Phonemogram
13DED		Logogram (beginning)
13DEE		Classifier fly/insect
13DEF		Classifier wasp
13DF0		Phonemogram
13DF1		Logogram (mantis)
13DF2		Classifier scorpion
13DF4		Classifier Serket/Selkis
13DF5	13DF6	Logogram (Serket/Selkis (divinity)
13DF7		Classifier tiny insect
13DF8		Classifier to open
13DF9		Classifier beetle
13DFA		Phonemogram
13DFB		Logogram (sycamore)
13DFD		Logogram (rain (divinity))
13DFE		Logogram (Neith, 4-5th nome of LE)
13DFF		Logogram (14th nome of UE)
13E00	13E01	Logogram (20-21st nome of UE)
13E02		Logogram (13th nome of UE)
13E03		Classifier tamarisk wood
13E05		Phono-repeater
13E06		classifier wood
13E07		Classifier wood
13E08		Classifier costly wood
13E09	13E0A	Classifier dom-palm
13E0B		Logogram (true of voice)
13E0D		Logogram (to be justified)
13E0F		Phono-repeater
13E10	13E11	Phonemogram
13E13		Phonemogram
13E14		Classifier plant
13E15		Classifier oil
13E16		Classifier plant?
13E17		Classifier plant
13E19	13E1B	Logogram (year)
13E1C		Phono-repeater
13E1D	13E1E	Logogram (year)
13E1F		Logogram (time/season)
13E20	13E21	Logogram (to be young, to rejuvenate)
13E22		Classifier/phono-repeater
13E23		Logogram (time/season)
13E26		Logogram (year)
13E27		Logogram (to be young, to rejuvenate)
13E2A		?
13E2D	13E2E	Phonemogram
13E2F		Logogram (marsh, meadow)
13E30		Classifier flower
13E31	13E36	Phonemogram
13E38		?
13E39		Classifier offering
13E3A		Classifier lettuce
13E3C		Classifier growing
13E3F		Logogram (to be good)
13E40		Classifier flower
13E41		Classifier plants/flowers
13E42		Classifier joy
13E43		Classifier plant/phono-repeater
13E44	13E45	Classifier joy
13E47		Classifier joy
13E48		Classifier flower
13E4A		Classifier flower
13E4B		Logogram (flower)
13E4C		Classifier flower
13E4D		Logogram (Wennefer, title of Osiris)
13E4E		Classifier plants, vegetables
13E4F		Logogram (lotus)
13E51		Logogram (lotus)
13E52	13E53	Classifier reed/rush
13E54	13E55	Classifier floral offering
13E58		Phonemogram
13E59	13E5A	Logogram (to offer)
13E5B	13E5C	Phonemogram
13E5D		Phonemogram ḫꜣ? (in the verb ḫꜣḫꜣ, to winnow, to scatter)
13E5E	13E5F	Phonemogram
13E60		Logogram (\1000)
13E61		Phonemogram
13E62		Logogram (\1000)
13E63		Classifier lotus leaf
13E64		Phonemogram
13E65		\4000
13E66	13E67	Phonemogram
13E6A		Logogram (lower Egypt)
13E6B		Phonemogram
13E6C	13E6E	Logogram (uraeus)
13E6F		Logogram (to gleam, to be bright, to dazzle)
13E70		Logogram (Upper Egypt)
13E73		Phonemogram
13E74		Classifier marsh/swamp
13E75		Logogram (Lower Egypt)
13E76		Phonemogram
13E77		Logogram (Lower Egypt)
13E78		Logogram (Upper Egypt)
13E79		Phonemogram
13E7A		Radicogram (grain of LE)
13E7B	13E7E	Logogram (Upper Egypt)
13E80		Phonemogram
13E81		Classifier plants
13E82		Logogram (Lower Egypt)
13E83		Classifier floral offering
13E84	13E86	Phonemogram
13E87	13E89	Logogram offering
13E8A		Logogram (marshland, country)
13E8B		Classifier reeds/rushes
13E8C		Phonemogram
13E8E	13E8F	Phonemogram
13E90		Logogram (Upper Egypt)
13E91		Phonemogram
13E92		Logogram (Upper Egypt)
13E93		Phonemogram
13E95		Logogram (Upper Egypt)
13E96		Logogram (custodian of the property of the king)
13E97		classifier plants
13E98		Logogram (Upper Egypt)
13E99		Phonemogram
13E9A		Logogram (King of UE)
13E9B		Phonemogram
13E9D		Logogram (to follow, to accompany)
13E9E		Classifier braided lock of hair
13E9F		Classifier succesfull, fortunate
13EA0		Logogram (succesful, fortunate)
13EA1	13EA2	Logogram (to be sweet)
13EA3		Classifier plants
13EA5		Classifier grain, barley, corn
13EA6		Logogram (emmer)
13EA8	13EA9	Phonemogram
13EAA		Classifier tying, binding
13EAB	13EAC	Phonemogram
13EAF		Phonemogram
13EB0		Classifier tying, binding
13EB1		Classifier vegetable, fruit, plant
13EB2		Logogram ((a vessel) with faience)
13EB3	13EB5	Phonemogram
13EB7		Logogram (gardiner, vinter)
13EB8		Classifier wine
13EB9		Classifier fig
13EBA		Classifier Min (mnw) or logogram ꜥbw (lettuce)
13EBB		Classifier unions
13EBC		Classifier plants
13EBE		Classifier lettuce
13EC0		Logogram (fig)
13EC2		Classifier lower sky
13EC3		Logogram (granary)
13EC4		Classifier affliction
13EC5		Classifier cavern
13EC6		Logogram (primeval waters)
13EC7		Classifier dark/darkness
13EC8		Classifier darkness (in divinity Keket (kk.t))
13EC9	13ECA	Classifier darkness
13ECB		Logogram (night)
13ECC		Classifier night
13ECD		Phonemogram
13ECE		Classifier dawn
13ECF		Logogram (dew, scent, rain)
13ED0		Classifier cloud/storm/moisture/rain
13ED1		Classifier cloudiness
13ED2		Classifier time
13ED3		Classifier divinity
13ED4	13EDA	Logogram (King of UE and LE)
13EDB		Classifier to scatter light, to illuminate
13EDD		Classifier to scatter light, to illuminate
13EDE	13EDF	Classifier light, shining, rising
13EE0		classifier sunfolk
13EE1		Classifier to shine
13EE2		Classifier light, shining, rising
13EE3		Classifier to scatter light, to illuminate
13EE4		Classifier solar period
13EE6		Classifier solar period
13EE7		Classifier to spread out
13EE8		Logogram (the winged scarab/sundisk)
13EE9		Classifier Horus of Edfu
13EEA		Logogram (to go forth)
13EEB	13EEC	Classsifier divinity
13EED	13EEE	Logogram (King of UE and LE)
13EEF		Logogram (to rise, to shine)
13EF0		Classifier winged sun-disk
13EF1	13EF2	Logogram (to rise, to shine)
13EF3		Logogram (in rꜥ-nb)
13EF5		Logogram (half-month (festival))
13EF6		Logogram (month)
13EF8		Logogram (to gleam, to be bright, to dazzle)
13EF9		Logogram (Upper Egypt)
13EFA		Logogram (Lower Egypt)
13EFB	13EFF	Logogram (land)
13F00		Logogram (Dendera)
13F01		Classifier great water/basin
13F02		Classifier geographical location
13F03		Classifier garden
13F04	13F06	Logogram (nome, district)
13F08		Logogram (9th nome of LE)
13F0A		Classifier garden
13F0C		Logogram (Prosopite Nome)
13F0D		Logogram (9th nome of UE)
13F0E		Logogram (20-21st nome of UE)
13F0F		Logogram (14th Upper Egyptian nome)
13F10		Logogram (21th Upper Egyptian nome)
13F11		Logogram (14th Upper Egyptian nome)
13F12		Logogram (14th upper Egyptian nome)
13F13		Logogram (18th Lower Egyptain nome (Pelusium))
13F14		Logogram (12th Upper Egyptian nome)
13F15		Logogram (Ha (divinity))
13F16		Logogram (foreign land/desert)
13F17		Classifier location
13F18	13F19	Logogram (place of life (i.e., the west))
13F1A		Classifier foreign land
13F1B		Logogram (the evil one)
13F1C	13F1D	Logogram (12th Upper Egyptian nome)
13F1E		Logogram (Ha (divinity))
13F1F		Classifier medicaments, incense, oil
13F20		Logogram (eternity)
13F21		Logogram (place of execution/slaughter)
13F23		Logogram (eternity)
13F24		Logogram (to appear, to be shining)
13F25	13F26	Logogram hill, mound
13F28		Logogram (Dendera)
13F29		Phonemogram
13F2A		Classifier entirely, quite, at all
13F2C		Classifier window
13F2D		Logogram (road)
13F2E		Classifier road, path
13F2F		Logogram (time)
13F30		Classifier decay, rot
13F31		Phonemogram
13F32		Logogram (island (in ꞽw-ḏsḏs (el-Bahriya oasis))
13F33		Logogram (Dendera)
13F34		Phonemogram
13F36		Classifier time
13F37		Classifier bank (river, fortress
13F38		Classifier waters, rivers, lakes
13F39		Classifier to dam, to revet
13F3A		Logogram (to wade)
13F3B	13F3C	Phonemogram
13F3E		Phonemogram
13F3F		Logogram (Hierakonpolis)
13F40		Logogram (island)
13F41		Logogram (to go)
13F43		Logogram (Dendera)
13F44	13F45	Phonemogram
13F46		Logogram (copper)
13F47		Classifier metal
13F48		Phonemogram
13F4A		Classifier (lightning bolt)
13F4C		Classifier two tombs
13F4D		Logogram (invocation offering)
13F4F		Logogram (temple)
13F50		Logogram temple)
13F51		Logogram (temple)
13F52		Logogram (houses, domains)
13F53		Logogram (court)
13F54		Classifier place, building
13F56		Logogram (temple, mansion, estate)
13F57		Logogram (temples, mansions, estates)
13F59		Logogram (temple, mansion, estate)
13F5B	13F5C	Logogram (temples, mansions, estates)
13F5D		Logogram (Hathor, lady (of))
13F60	13F61	Logogram (Nephthys (divinity))
13F62	13F63	Logogram (palace)
13F65		Classifier palace
13F67		Logogram (palace)
13F69		Classifier divine
13F6A	13F6D	Phonemogram
13F6E		Logogram (court of offerings)
13F72		Logogram (wall)
13F73	13F74	Classifier overthrow, demolish
13F75		Classifier geographical location
13F76		Classifier geographical location (Elephantine)
13F78		Classifier wall
13F79		Logogram i(Memphis (the white wall))
13F7B		Logogram (serekh (palace) façade)
13F7C		Classifier palace façade
13F7F		Classifier palace façade
13F80	13F81	Logogram (serekh (palace) façade)
13F82	13F83	Logogram (chapel)
13F84	13F87	Logogram (serekh (palace) façade)
13F88		Classifier pylon/gateway
13F8A		Logogram (sanctuary of Upper Egypt)
13F8B		Classifier doorway/gateway
13F8C		Logogram
13F8D	13F8E	Logogram (chapel)
13F8F		Phonemogram (in r-rw.t (outside))
13F90		Logogram (palace)
13F91		Logogram (portal, portico)
13F92		Classifier doorway
13F93		Phonemogram (in r-rw.t (outside))
13F94		Logogram (doorway)
13F95		Classifier portal, portico
13F96		Classifier tomb
13F98		Classifier portal, portico
13F99		Logogram (main gate of a temple)
13F9A		Classifier curtain
13F9C		Classifier funerary chapel, cenotaph
13F9D		Classifier chapel
13F9E		Logogram (sanctuary of Upper Egypt)
13F9F		Logogram (to be divine)
13FA1		Classifier shrine
13FA2	13FA3	Logogram (sanctuary of Upper Egypt)
13FA5	13FA6	Classifier shrine
13FA7		Classifier chapel (associated with Min)
13FA8		Logogram (Ennead)
13FA9		Classifier shrine
13FAB		Logogram (sanctuary of Sokar)
13FAC		Classifier sanctuary, shrine
13FAD		Logogram (shrine, row of shrines)
13FAE		Logogram (Dendera)
13FB1		Logogram (sanctuary of Upper Egypt)
13FB3		Logogram (portal, portico)
13FB4		Logogram (ceiling, heaven)
13FB5		Logogram (portal, portico)
13FB6		?Logogram (shrine?)
13FB7		Logogram (pavilion, hall, booth)
13FB8		Logogram (to tie on, to don)
13FBB		Logogram (divine booth)
13FBC		Logogram (booth)
13FBD		Phonemogram
13FBE		Phonemogram (in ꜥrḳ-wr)
13FBF		Phonemogram
13FC0		Logogram (jubilee, sed-festival)
13FC1		Classifier throne dais
13FC3		Logogram (jubilee, sed-festival)
13FC4		Logogram (four)
13FC5	13FC6	Logogram (jubilee, sed-festival)
13FC9		Logogram (jubilee, sed-festival)
13FCA	13FCB	Classifier jubilee, sed-festival
13FCC		Logogram (jubilee, sed-festival)
13FCD		Logogram (festival)
13FCE	13FD0	Logogram (jubilee, sed-festival)
13FD2	13FD4	Logogram (jubilee, sed-festival)
13FD5		Logogram (festival)
13FD6		Logogram (ceiling, heaven)
13FD7		Phonemogram/Logogram
13FD8		Classifier to ascend, to mount up
13FD9		?
13FDA		Classifier obelisk
13FDB		Phonemogram/logogram (to beget, to ejaculate, to create)
13FDC		Classifier solar temple
13FDD		Classifier shrine/chapel
13FDE		Logogram (shrine, row of shrines)
13FDF	13FE2	Phonemogram
13FE4		Logogram (papyriform column)
13FE5		Classifier column (columned hall)
13FE7		Classifier column (columned hall)
13FEA		Phonemogram
13FEB		Classifier Pillar
13FEC		Logogram (face, sight)
13FEE	13FEF	Classifier door-bolt
13FF0		Classifier door bolt
13FF1	13FF2	Phonemogram
13FF3		Classifier gateway
13FF4		Classifier dais, terrace, platform
13FF5	13FF7	Phonemogram
13FFA	13FFB	Phonemogram
13FFD		Logogram (field, arable land)
13FFE		Phonemogram
14000		Classifier granary
14002	14003	Logogram (granary)
14005		Logogram (granary)
14006	14007	Logogram (ornament)
14008		Classifier tower
14009		Classifier to ascend, to mount up
1400A		Logogram (the emblem of the cult of Min)
1400B	1400C	Logogram (office, rank, function)
1400D		Classifier Harim, inner chamber
1400E	14010	Phonemogram
14011	14012	Logogram (Hierakonpolis)
14014		Classifier part of a building
14017		Classifier conflagration
14018		Logogram (fortress)
14019		Classifier stair
1401A		Classifier movement
1401B		Classifier boat/ship/bark
1401C		Logogram (ship, boat, bark)
1401D	1401F	Classifier movement
14020		Classifier to upset, to overturn
14021		Classifier movement
14022		Classifier boat/ship
14023		Classifier movement
14024		Phonemogram
14025		Classifier (to capsize)
14026		Phonemogram
14027		Classifier mooring
14028		Classifier boat/ship
14029		Classifier death
1402B		Logogram (ship, boat, bark)
1402F	14030	Classifier bark/boat
14031		Logogram (ship, boat, bark)
14032	14036	Classifier bark/boat
14037		Classifier papyrus float
14038		Classifier movement
14039		Logogram (ship, boat, bark)
1403A		Logogram (bark of the king/royal bark)
1403C		Logogram (ship, boat, bark)
1403F		Logogram (to go south (sailing upstream))
14040		Classifier sailing upstream/going south
14041		Logogram (to go south (sailing upstream))
14042		Classifier sailing upstream/going south
14043		Classifier boat/ship
14044		Logogram (ship, boat, bark)
14045		Classifier bark/boat
14046		Logogram/classifier (bark/boat)
14048	14049	Classifier boat/ship
1404B	1404C	Classifier boat/ship
1404D		Logogram wiA(ship, boat, bark)
1404E		Logogram (ship, boat, bark)
1404F		Logogram (Amon-Re)
14050		Phonemogram
14051		Logogram
14052		Classifier boat/ship
14054		Classifier bark/boat
14056		Logogram (Bark of the two divine falcons)
14057	14058	Classifier bark
14059		Logogram (Sothis)
1405A		Logogram (Orion (constellation))
1405C		Classifier bark
1405E	1405F	Logogram (protection)
14061		Phonemogram
14062	14063	Logogram (cloth, clothing)
14065		Logogram ḥnw (Henu-bark of Sokar) or phonemogram skr
14066	14067	Logogram (Henu-bark of Sokar)
14068	1406A	Classifier bark of Sokar
1406B		Logogram (Henu-bark of Sokar)
1406C		Classifier bark of Sokar
1406D	1406F	Logogram (Henu-bark of Sokar)
14070	14071	Logogram (Sokar)
14073	14074	Logogram (Henu-bark of Sokar)
14075		Logogram (Sokar)
14076	14077	Phonemogram
14078		Logogram (to loosen, to explain)
14079	1407A	Classifier boat/ship
1407C		Logogram (wind, breath, air)
1407D		Classifier wind, breath, air
1407E		Logogram (wind, breath, air)
14080		Classifier wind, breath, air
14081		Logogram (wind, breath, air)
14082		Classifier wind, breath, air
14084	14085	Classifier wind, breath, air
14086		Logogram (wind, breath, air)
14088		Logogram (wind, breath, air)
14089		Classifier wind, breath, air
1408A		Logogram (wind, breath, air)
1408B	1408D	Phonemogram
14090		Logogram (snake divinity)
14093		Phonemogram
14094		Classifier (ferries/bridges)
14095		Phonemogram
14097		Phonemogram
14099	1409B	Phonemogram
1409C		Classifier throne
1409E		Classifier seat, chair, throne
1409F		Classifier seat/chair
140A0		Classifier carrying chair
140A1		Logogram (seat, throne, place)
140A3		Phonemogram
140A4		Classifier (sedan chair)
140A5		Classifier (seat with backrest?)
140A6		Classifier headrest
140A8		Classifier to rest
140A9		Classifier inclined bed
140AA		Classifier seat/chair
140AB		Classifier bed
140AC		Classifier to sleep/to spend the night
140AD		Classifier bed
140AF		Logogram (throne dais)
140B0		Logogram (mirror)
140B1		Classifier mirror
140B2		Classifier box
140B3	140B5	Logogram (requirements, needs)
140B6		Classifier box/chest
140B7		Logogram (box/chest)
140B8		Classifier offering table
140B9		Classifier shrine/chapel
140BA		Classifier to raise
140BB		Classifier to bury
140BC		Classifier burial
140BD		Classifier box
140BF		Logogram (crocodopolis)
140C1		Classifier burial
140C2		Classifier coffin
140C3		Classifier burial
140C4		Logogram (to bind)
140C5		Classifier burial
140C6		Logogram (temperature, temperament)
140C7		Logogram (fire)
140C8		Classifier fire associated action
140CA		Classifier brazier
140CB		Classifier (burning festival)
140CC	140CD	Classifier hearthstones
140CE		Classifier ladder
140CF		Classifier altar
140D0		Logogram (altar)
140D6		Classifier supplies, provisions
140D8		Classifier table
140DA	140DE	Classifier table
140E1		Classifier altar
140E2		Classifier offering table
140E3		Classifier altar, offering table
140E4		Logogram (altar of offerings)
140E5		Logogram (jar-stand, sideboard)
140E6		Logogram (offerings)
140E7		Classifier altar
140EA		classifier altar
140EC	140ED	Logogram (altar)
140EE		Classifier altar
140EF		Logogram (altar)
140F0		Classifier altar
140F1		Logogram (altar)
140F3		Classifier fumigation/censing
140F4		Classifier incense fire
140F6		Phonemogram/logogram (to satisfy)
140F9		Logogram (incense)
140FC		Logogram (gods)
140FD		Logogram (all the gods)
140FE		Logogram (Ennead)
140FF		Logogram (god and goddess)
14100	14101	Logogram (gods and goddesses)
14102		Logogram (god and goddess)
14104		Logogram (Natron)
14105	14107	Logogram (necropolis)
14109	1410E	Logogram (necropolis)
14110		Logogram (necropolis)
14111		Logogram (18th UE nome)
14112	14114	Phonemogram
14115		Classifier standard
14116		Classifier pole
14117		Logogram (standard)
14118		Classifier standard
14119		Classifier mirror
1411B		Logogram (Duau (divinity))
1411C		Logogram spd.t (Sothis) or ẖn.ty ꞽꜣb.t (foremost of the east)
1411D		Logogram (Duau (divinity))
1411E		Logogram (border, boundry)
1411F	14120	Logogram (west)
14121		Logogram (right, right side)
14122		Logogram (west)
14124		Logogram (west)
14126		Logogram (west)
14128		Phonemogram
14129		Logogram (east)
1412A		Radicogram (left eye)
1412B	1412D	Logogram (east)
1412F		Logogram (east)
14131		Phonemogram
14132		Radicogram (left eye)
14136	14137	Logogram (8th nome of Upper Egypt)
14138		Logogram (Abydos)
1413A	1413C	Logogram (Abydos)
1413E		Phonemogram
1413F	14140	Logogram (Nefertem)
14141	14142	Logogram (Thebes)
14144		Logogram (Seshat (divinity))
14145		Logogram (Letopolis)
14147		Logogram (Min (divinity))
14148		Classifier document holder
14149		Logogram/Classifier (the one of Shedet (i.e., Sobek)
1414C		Classifier (base, pedestal, plinth (of a shrine))
1414D		Classifier crown
1414E		Logogram (the white crown)
1414F		Logogram (wearer of the sash (priest))
14150		Logogram (the white crown)
14151		Logogram (Tatenen (divinity))
14152		Logogram (Baby (divinity))
14153		Logogram (Upper Egypt)
14154	14155	Classifier crown
14156		Logogram (to be divine)
14157		Logogram (Lower Egypt)
14158		Classifier crown
14159		Phonemogram
1415A		Classifier the red crown
1415B		Classifier double crown
1415C		Logogram (cap, crown)
1415D		Logogram/phonemogram (carpenter)
1415E	1415F	Phonemogram
14160	14162	Classifier headcloth
14164	14165	Logogram (to bind, to wind around)
14166		Classifier crown
14168	14169	Logogram (Atef-crown)
1416B	1416D	Logogram (Hemhem-crown)
1416E	14170	Logogram (double plumes/two feather crown)
14173		Logogram (the four feather crown)
14174	14177	Logogram (double plumes/two feather crown)
14178		Phonemogram
14179		Logogram (Elkab)
1417A		Phonemogram
1417B		Classifier crown
1417C		Phonemogram
1417D		Logogram (3rd nome of Upper Egypt)
1417E		Classifier two halfs
1417F		Phonemogram
14180		Logogram (the horizon)
14181		Logogram (who goes forth from the horizon)
14182	14186	Logogram (wreath, garland)
14187		Classifier collar
14189	1418B	Classifier collar
1418C		Logogram collar
1418D	1418E	Classifier collar
14190	14191	Logogram (necklace, collar)
14192		Classifier vessel (twin vases for myrrh)
14194		Classifier wreath, garland
14195		Logogram (necklace)
14196		Logogram (to be bright)
14197		Logogram (to be bright) or Classifier dew/scent/rain
14199		Logogram (brightness)
1419A		Logogram (to be bright)
1419C		Logogram (to be bright)
1419D		Logogram (faience)
1419E		Classifier place/divinity
1419F		Logogram (menit necklace)
141A1		Logogram (menit necklace)
141A2		Classifier necklace
141A4		Classifier pectoral
141A5	141A6	Classifier amulet
141A7		Classifier amulet (Logogram in line 3)?
141A8	141AB	Phonemogram
141AC		Classifier cloth/garment
141AD		Classifier bracelet, anklet
141AF		Logogram (kilt, royal apron)
141B0		Classifier garment
141B1		Logogram (clothing)
141B2		Classifier cloth
141B3	141B4	Logogram (clothing)
141B5		Classifier cloth
141B6		Logogram (six-weave linen)
141B7		Logogram (linen)
141B8		Phonemogram
141B9		Classifier clothing
141BA		Phonemogram
141BD	141C1	Phonemogram
141C2	141C3	Classifier cloth
141C5		classifier time
141C6		Classifier Ankh vessel
141C7		Logogram (stability and life)
141C8		Logogram (all life, stability and dominion)
141C9		Logogram (all life and dominion)
141CB		Phonemogram
141CC		Logogram (shadow, shade)
141CD		Phono-repeater/classifier (in ḥp.ty (extreme limits))
141CE	141D0	Phonemogram
141D2		Logogram (fan)
141D4		Logogram (Igai (divinity))
141D5	141D6	Phonemogram/Logogram (iatet drink)
141D7		Logogram (Iat (divinity)
141D8		Logogram (district, region)
141DA	141DC	Phonemogram
141DD		Classifier sceptre
141DE		Logogram (Hetes-staff, baton)
141DF		Logogram (ames-sceptre)
141E0		Classifier staff, sceptre
141E1		Classifier clothing
141E2	141E4	Phonemogram
141E5	141E8	Logogram (to judge, to separate)
141E9	141EA	Phonemogram
141EB		Logogram (counterweight)
141EC		Phonemogram
141ED		Classifier to spit, to expel
141EE		Phonemogram
141F0		Phonemogram
141F1		Classifier (curl)
141F2		Classifier (bracelet)
141F3		Classifier cloth/garment
141F4		Classifier cloth
141F5		Classifier dignity, rank
141F6		Logogram (abode, birth place, birthing brick)
141F7		Logogram (mace)
141FB	141FD	Phonemogram
141FE		Phonemogram/logogram (white crown)
141FF		Logogram (silver)
14200		Phonemogram (in (tꜣ)-ṯnn (divinity))
14201	14202	Classifier shield
14203		Logogram (shield)
14204		Logogram (carpenter, shipwright)
14205		Classifier (strainer, colander)
14206		Logogram (metal)
14207	14208	Phonemogram
14209		Logogram/phonemogram (to stretch out)
1420A		Classifier beyond, outside
1420B		Phonemogram/logogram
1420C		Classifier (arrow)
1420D		Phonemogram
1420E		Logogram (Synene (Aswan))
1420F		Phono-repeater
14210	14211	Phonemogram
14213		Logogram (Neith)
14214	14217	Logogram (Neith, 4-5th nome of LE)
14218		Logogram (Neith-north, 5th nome of LE)
14219		Logogram (Neith-south, 4th nome LE)
1421B	1421C	Logogram (Neith-south, 4th nome LE)
1421D		Phonemogram
1421F		Classifier feminine life force
14220		Phonemogram
14221		Logogram (back)
14222	14224	Phonemogram
14225		Phonemogram/logogram (mother)
14226	14227	Phonemogram
14228		Phono-repeater
14229		Phonemogram
1422A		Phono-repeater
1422B		Phonemogram/logogram (strife)
1422D		Logogram/phonemogram (meter canal)
1422E		Phonemogram
1422F		Logogram (to be strong, brave, capable)
14230		Logogram (valour, strength)
14231		Logogram (Khopesh sword/scimitar)
14232		Classifier to be strong, brave, capable
14233		Logogram (Khopesh sword/scimitar)
14234		Logogram (to be strong, brave, capable)
14235		Logogram (to follow)
14236		Logogram (follower, retainer)
14237		Logogram (to follow)
14238		Classifier stalk, reed
1423A		Phono-repeater
1423B		Phonemogram
1423C		Phono-repeater
1423D	14240	Phonemogram
14241	14243	Logogram (one, sole)
14245	14248	Logogram (one, sole)
14249		Classifier lance, spear
1424A	1424D	Phonemogram
14250	14251	Logogram (7-8th nome of Lower Egypt)
14253		Logogram (7th nome of Lower Egypt)
14256		Logogram (7th nome of Lower Egypt)
14259		Phonemogram
1425A		Logogram (net)
1425B	1425C	Classifier catching, netting
1425D		Logogram (net)
1425E		Classifier net
1425F		Classifier catching, netting
14260		Classifier fish-trap
14261	14263	Phonemogram
14265		Phonemogram
14268	1426A	Phonemogram
1426B		Logogram (to weave, to trap)
1426C		Phono-repeater
1426D		Phonemogram
1426E		Classifier catching, netting
1426F		Classifier shelter
14270	14271	Classifier net
14272		Logogram (net)
14273		Classifier fish-trap
14274		Classifier cutting, slaughter
14275		Logogram (flint, in ds-km, obsidian)
14276	14278	Logogram (to carve, to enscribe, to engrave)
1427A		Classifier place of execution
1427B		Logogram (place of execution)
1427C		Logogram (place of slaughter)
1427D	1427E	Logogram (butchery, slaughter)
1427F		Logogram (place of execution)
14280		Logogram (to carve, to enscribe, to engrave)
14282		Classifier stench
14283		Logogram (place of slaughter)
14285		Phonemogram
14287		Phonemogram
14289		Classifier to spread (in psš-kf (a type of flint knife))
1428A		Classifier to cause to breathe
1428B		Classifier points (of a harpoon)
1428C		Classifier hooks
1428D		Classifier circumcision
1428F		Phonemogram
14290	14291	Classifier hacking
14292		Logogram (to hack the land)
14293		Classifier hacking
14294		Phonemogram
14296		Classifier harvest, crop
14297		Classifier grain/barley
14298	1429A	Classifier grain
1429C		Phonemogram
1429D		Phono-repeater
1429F		Phono-repeater
142A1	142A2	Logogram (fruit)
142A3	142A4	Phonemogram
142A6		Phonemogram
142A7		Classifier burial
142A8		Logogram (Re-Atoum)
142A9	142AA	Logogram (to found, to establish, to hunt, to lay (a trap))
142AB		Classifier claw, nail
142AC		Phonemogram
142AD		Logogram (nail)
142AE		Phonemogram
142AF		Classifier claw, nail
142B0	142B3	Phonemogram
142B4		Classifier chisel
142B5		Phonemogram
142B7	142BA	Phonemogram
142BB		Classifier drilling
142BC	142BD	Phonemogram
142BE		Logogram (to open)
142BF		Phonemogram
142C1		Logogram (to open)
142C2		Phonemogram
142C4		Phonemogram
142C5		Logogram (craftsman)
142C6		Phonemogram
142C7		Logogram (to open)
142C8		Phonemogram
142C9		Logogram (craftsman)
142CA		Logogram (to open)
142CB		Logogram (craftsman)
142CD		Logogram (skilled)
142CE		Logogram (craft)
142D0		Logogram (craftsman)
142D1		Logogram (to open)
142D3		Logogram (craftsman)
142D4	142D6	Logogram (to open)
142D7	142DA	Phonemogram
142DB		Phono-repeater
142DC	142DE	Phonemogram
142DF		Classifier shaving
142E0		Logogram (to shave)
142E2		Classifier balance, scale
142E3		Logogram (balance, in mḫꜣ.t-tꜣ.wy)
142E4		Classifier balance, scale
142E5		Logogram (to lift, to raise)
142E8		Classifier lifting, carrying
142E9	142EB	Logogram (to lift, to carry)
142EC		Classifier lifting, carrying
142EE		Classifier to raise to lift up
142EF		Classifier measuring tool?
142F0	142F1	Classifier lifting, carrying
142F2		Phonemogram (ꞽn wṯs-ḥr)
142F3		Classifier service, task
142F4		Logogram (service, task)
142F6		Logogram (service, task)
142F7		Classifier astronomical instrument
142F8		Logogram (service, task)
142F9		Classifier length, width
142FA		Phonemogram
142FB		Classifier to shape, to create
142FC		Logogram (life)
142FD		Classifier potter's wheel
142FE		Classifier potter
142FF		Logogram (potter's wheel)
14300		Classifier potters wheel
14303	14304	Logogram (Chesemu (divinity))
14306	14308	Logogram (Chesemu (divinity))
1430B		Logogram (Chesemu (divinity))
1430F		Logogram (to press, to cling (to))
14310		Classifier pressing, hitting
14312		Phonemogram
14313		Classifier gold-dust
14314		Classifier cage
14315		Classifier cauldron
14317	14318	Phonemogram
14319		Classifier flame
1431A		Classifier sweeping, wiping
1431B		Classifier saw
1431C		Classifier (upright of an ladder)
1431D		Phonemogram
1431F		Logogram (field, arable land)
14320		Phono-repeater sṯꜣ and classifier movement sṯꜣ&
14321		Phono-repeater
14322		Classifier clothing
14323		Phonemogram
14324		Logogram (cult image?)
14325		Logogram (name)
14327		Logogram (float? (part of the hunting equipment for hunting hippos))
14329	1432C	Phonemogram
1432D	1432E	Logogram (protection)
1432F		Phonemogram
14331	14332	Logogram (19th nome of Upper Egypt)
14333	14334	Phonemogram
14336		Phonemogram
14337	14339	Interpretant
1433B		Phonemogram
1433C		Classifier to dispel, to drive away
1433D		Logogram (to strike, to drive)
1433E	14341	Phonemogram
14342		Classifier (wick)
14343	14345	Phonemogram
14346		Classifier (offering)
14348	1434A	Phonemogram
1434B		Phono-repeater
1434C	1434F	Phonemogram
14350		Phono-repeater
14352	14354	Phonemogram
14355		Logogram/phonemogram (womb)
14356		Phonemogram
14357	14358	Logogram (net)
14359		Classifier oil, unguent
1435A	1435B	Phonemogram
1435C	1435D	Classifier oil, unguent
1435E		Classifier liquid, fluid
1435F	14360	Classifier oil, unguent
14361		Classifier/logogram oil, unguent
14362		Logogram/Phonemogram (oil, unguent)
14363		Logogram (lord)
14364		Logogram (lector priest)
14366	14367	Phonemogram
14369	1436B	Phonemogram
1436C		Logogram (cup)
1436D		Phonemogram
1436E		Classifier jar, vessel
1436F		Classifier cool
14370		Classifier to be cool, to cool
14371		Logogram (cool water/libation water)
14372		Classifier to pour, to sprinkle
14373		Logogram (to be cool, to cool)
14374		Logogram (cool water/libation water)
14375		Logogram (the (first) cataract)
14376		Phonemogram/logogram (in ḳbḥ.wy (the two sources, i.e., Egypt))
14377		Logogram (the two sources, i.e. Egypt)
14378		Logogram (cool water/libation water)
14379	1437D	Phonemogram
1437F		Phonemogram
14380	14381	Classifier milk
14384		Phonemogram
14385		Classifier vessel (situla?)
14386		Logogram (to be pure, to be clean)
14387		Classifier to pour out, to empty
14388		Phonemogram
14389		Classifier beer-jug
1438B		Classifier drunkenness
1438C		Classifier wine
1438F		Classifier liquid, fluid
14390		Classifier jar
14391		Classifier oil, unguent
14392		Logogram diw-(the five pellets)
14393		Classifier jug
14395	14396	Phonemogram
14397		Logogram (Elephantine)
14399		Classifier liquid, fluid
1439A		Classifier jar, vessel
1439B		Classifier breaking, destroying
1439C		Classifier alcoholic beverage
1439D		Logogram (libation vase)
1439E		Classifier to fill
1439F		Classifier vessel
143A0	143A1	Classifier jar, vessel
143A2		Classifier (to wash)
143A3		Logogram (Nemset vase)
143A4		Classifier vessel
143A5		Classifier vessel, jar
143A7		Classifier jar, vessel
143A8	143A9	Classifier drinking vessel
143AB		Classifier dish
143AE		Logogram (some type of vessel)
143AF		Classifier milk
143B0		Classifier vessel (which might be some type of oil)
143B3		Logogram (beer)
143B4		Logogram (gold vase for myrrh)
143B5		Classifier oven
143B7		?
143B8		Classifier granite
143B9		Phonemogram
143BA		Logogram (a nw-vase, representing an amulet of lapis-lazuli)
143BB		Classifier basin for washing feet
143BC	143BE	Logogram (father)
143C0	143C1	Classifier bread
143C2		Classifier bread/food
143C4		Classifier food
143C5		Classifier festival
143C6		Classifier food
143C7		Classifier offering
143C8		Logogram (type of bread)
143C9		Logogram (to pass by)
143CB		Phonemogram
143CC		Classifier offering, cake, loaf
143CE		Classifier bread
143CF		Classifier abstract words
143D0		Classifier double flute
143D1		Logogram (to write, to draw)
143D2		Logogram (scribe)
143D3		Classifier red
143D4		Classifier scribal pallet
143D5		Classifier (scribal water pot)
143D7		Classifier writing tablet
143D8		Classifier snake-game
143D9	143DA	Phonemogram
143DB	143DD	Logogram (to say, to speak)
143DE	143DF	Classifier tambourine
143E0		Logogram (ball)
143E1		Classifier sistrum
143E2		Logogram (sistrum)
143E3		Classifier sistrum
143E4	143E5	Logogram (sistrum)
143E6		Classifier head-piece of a sistrum
143E7		Classifier plural
143E9	143EA	Phonemogram
143EE		Logogram (1/2 aroura)
143EF		Classifier writing tablet
143F0		Classifier enemy, opponent
143F7		Logogram
143F8		Phonemogram
143FA		Phonemogram
END
